@@ -2,7 +2,7 @@
 # https://asv.readthedocs.io/en/latest/writing_benchmarks.html
 import numpy as np
 
-from skimage import data, filters
+from skimage import data, filters, color
 from skimage.filters.thresholding import threshold_li
 
 
@@ -30,15 +30,11 @@ class FiltersSobel3D:
         _ = filters.sobel(self.image3d)
 
 
-class MultiOtsu(object):
+class MultiOtsu:
     """Benchmarks for MultiOtsu threshold."""
     param_names = ['classes']
     params = [3, 4, 5]
     def setup(self, *args):
-        try:
-            from skimage.filters import threshold_multiotsu
-        except ImportError:
-            raise NotImplementedError("threshold_multiotsu unavailable")
         self.image = data.camera()
 
     def time_threshold_multiotsu(self, classes):
@@ -82,10 +78,10 @@ class ThresholdSauvolaSuite:
         self.image3D[:, idx3D, idx3D] = 255
 
     def time_sauvola(self):
-        result = filters.threshold_sauvola(self.image, window_size=51)
+        filters.threshold_sauvola(self.image, window_size=51)
 
     def time_sauvola_3d(self):
-        result = filters.threshold_sauvola(self.image3D, window_size=51)
+        filters.threshold_sauvola(self.image3D, window_size=51)
 
 
 class ThresholdLi:
@@ -99,7 +95,54 @@ class ThresholdLi:
         self.image_float32 = self.image.astype(np.float32)
 
     def time_integer_image(self):
-        result1 = threshold_li(self.image)
+        threshold_li(self.image)
 
     def time_float32_image(self):
-        result1 = threshold_li(self.image_float32)
+        threshold_li(self.image_float32)
+
+
+class RidgeFilters:
+    """Benchmark ridge filters in scikit-image."""
+
+    def setup(self):
+        # Ensure memory footprint of lazy import is included in reference
+        self._ = filters.meijering, filters.sato, filters.frangi, filters.hessian
+        self.image = color.rgb2gray(data.retina())
+
+    def peakmem_setup(self):
+        """peakmem includes the memory used by setup.
+        Peakmem benchmarks measure the maximum amount of RAM used by a
+        function. However, this maximum also includes the memory used
+        by ``setup`` (as of asv 0.2.1; see [1]_)
+        Measuring an empty peakmem function might allow us to disambiguate
+        between the memory used by setup and the memory used by slic (see
+        ``peakmem_slic_basic``, below).
+        References
+        ----------
+        .. [1]: https://asv.readthedocs.io/en/stable/writing_benchmarks.html#peak-memory
+        """
+        pass
+
+    def time_meijering(self):
+        filters.meijering(self.image)
+
+    def peakmem_meijering(self):
+        filters.meijering(self.image)
+
+    def time_sato(self):
+        filters.sato(self.image)
+
+    def peakmem_sato(self):
+        filters.sato(self.image)
+
+    def time_frangi(self):
+        filters.frangi(self.image)
+
+    def peakmem_frangi(self):
+        filters.frangi(self.image)
+
+    def time_hessian(self):
+        filters.hessian(self.image)
+
+    def peakmem_hessian(self):
+        filters.hessian(self.image)
