@@ -9,12 +9,12 @@ class ImportSuite:
         'skimage.feature',
         'skimage.morphology',
         'skimage.color',
+        'skimage.io',
     ]
     param_names = ["package_name"]
     def setup(self, package_name):
         pass
 
     def time_import(self, package_name):
-        results = run(executable + ' -c "import ' + package_name + '"',
-            stdout=PIPE, stderr=PIPE, stdin=PIPE, shell=True)
-
+        run(executable + ' -c "import ' + package_name + '"',
+            capture_output=True, stdin=PIPE, shell=True)
