@@ -13,7 +13,7 @@ if 'indices' in parameters and parameters['indices'].default:
     peak_kwargs = {'indices': False}
 
 
-class PeakLocalMaxSuite(object):
+class PeakLocalMaxSuite:
 
     def setup(self):
         mask = np.zeros([500, 500], dtype=bool)
@@ -28,6 +28,7 @@ class PeakLocalMaxSuite(object):
         self.dist = ndi.distance_transform_edt(mask)
 
     def time_peak_local_max(self):
-        local_max = peak_local_max(
+        peak_local_max(
             self.dist, labels=self.labels,
-            min_distance=20, exclude_border=False, **peak_kwargs)
+            min_distance=20, exclude_border=False, **peak_kwargs
+        )
