@@ -3,7 +3,10 @@
 Explore 3D images (of cells)
 ============================
 
-This tutorial is an introduction to three-dimensional image processing. Images
+This tutorial is an introduction to three-dimensional image processing.
+For a quick intro to 3D datasets, please refer to
+:ref:`sphx_glr_auto_examples_data_plot_3d.py`.
+Images
 are represented as `numpy` arrays. A single-channel, or grayscale, image is a
 2D matrix of pixel intensities of shape ``(n_row, n_col)``, where ``n_row``
 (resp. ``n_col``) denotes the number of `rows` (resp. `columns`). We can
@@ -43,7 +46,11 @@ import matplotlib.pyplot as plt
 from mpl_toolkits.mplot3d.art3d import Poly3DCollection
 import numpy as np
 
-from skimage import exposure, io, util
+import plotly
+import plotly.express as px
+from skimage import (
+    exposure, util
+)
 from skimage.data import cells3d
 
 
@@ -71,15 +78,18 @@ print(f'rescaled spacing: {rescaled_spacing} (after downsampling)\n')
 print(f'normalized spacing: {spacing}\n')
 
 #####################################################################
-# Let us try and visualize the (3D) image with `io.imshow`.
+# Let us try and visualize our 3D image. Unfortunately, many image viewers,
+# such as matplotlib's `imshow`, are only capable of displaying 2D data. We
+# can see that they raise an error when we try to view 3D data:
 
 try:
-    io.imshow(data, cmap="gray")
+    fig, ax = plt.subplots()
+    ax.imshow(data, cmap='gray')
 except TypeError as e:
     print(str(e))
 
 #####################################################################
-# The `io.imshow` function can only display grayscale and RGB(A) 2D images.
+# The `imshow` function can only display grayscale and RGB(A) 2D images.
 # We can thus use it to visualize 2D planes. By fixing one axis, we can
 # observe three different views of the image.
 
@@ -101,20 +111,15 @@ show_plane(c, data[:, :, n_col // 2], title=f'Column = {n_col // 2}')
 
 #####################################################################
 # As hinted before, a three-dimensional image can be viewed as a series of
-# two-dimensional planes. Let us write a helper function, `display`, to
-# display 30 planes of our data. By default, every other plane is displayed.
+# two-dimensional planes. Let us write a helper function, `display`, to create
+# a montage of several planes. By default, every other plane is displayed.
 
 
-def display(im3d, cmap="gray", step=2):
-    _, axes = plt.subplots(nrows=5, ncols=6, figsize=(16, 14))
-
-    vmin = im3d.min()
-    vmax = im3d.max()
-
-    for ax, image in zip(axes.flatten(), im3d[::step]):
-        ax.imshow(image, cmap=cmap, vmin=vmin, vmax=vmax)
-        ax.set_xticks([])
-        ax.set_yticks([])
+def display(im3d, cmap='gray', step=2):
+    data_montage = util.montage(im3d[::step], padding_width=4, fill=np.nan)
+    _, ax = plt.subplots(figsize=(16, 14))
+    ax.imshow(data_montage, cmap=cmap)
+    ax.set_axis_off()
 
 
 display(data)
@@ -124,10 +129,12 @@ display(data)
 # Jupyter widgets. Let the user select which slice to display and show the
 # position of this slice in the 3D dataset.
 # Note that you cannot see the Jupyter widget at work in a static HTML page,
-# as is the case in the scikit-image gallery. For the following piece of
-# code to work, you need a Jupyter kernel running either locally or in the
-# cloud: see the bottom of this page to either download the Jupyter notebook
-# and run it on your computer, or open it directly in Binder.
+# as is the case in the online version of this example. For the following
+# piece of code to work, you need a Jupyter kernel running either locally or
+# in the cloud: see the bottom of this page to either download the Jupyter
+# notebook and run it on your computer, or open it directly in Binder. On top
+# of an active kernel, you need a web browser: running the code in pure Python
+# will not work either.
 
 
 def slice_in_3D(ax, i):
@@ -212,7 +219,7 @@ def explore_slices(data, cmap="gray"):
     return display_slice
 
 
-explore_slices(data);
+explore_slices(data)
 
 #####################################################################
 # Adjust exposure
@@ -273,7 +280,7 @@ display(equalized_data)
 # As before, if we have a Jupyter kernel running, we can explore the above
 # slices interactively.
 
-explore_slices(equalized_data);
+explore_slices(equalized_data)
 
 #####################################################################
 # Let us now plot the image histogram before and after histogram equalization.
@@ -308,3 +315,23 @@ clipped_data = exposure.rescale_intensity(
 )
 
 display(clipped_data)
+
+#####################################################################
+# Alternatively, we can explore these planes (slices) interactively using
+# `Plotly Express <https://plotly.com/python/sliders/>`_.
+# Note that this works in a static HTML page!
+
+fig = px.imshow(data, animation_frame=0, binary_string=True)
+fig.update_xaxes(showticklabels=False)
+fig.update_yaxes(showticklabels=False)
+fig.update_layout(
+    autosize=False,
+    width=500,
+    height=500,
+    coloraxis_showscale=False
+)
+# Drop animation buttons
+fig['layout'].pop('updatemenus')
+plotly.io.show(fig)
+
+plt.show()
