@@ -28,7 +28,6 @@ functions only work on gray-scale or binary images, so we set ``as_gray=True``.
 import matplotlib.pyplot as plt
 from skimage import data
 from skimage.util import img_as_ubyte
-from skimage import io
 
 orig_phantom = img_as_ubyte(data.shepp_logan_phantom())
 fig, ax = plt.subplots()
@@ -49,81 +48,83 @@ def plot_comparison(original, filtered, filter_name):
     ax2.set_title(filter_name)
     ax2.axis('off')
 
+
 ######################################################################
 # Erosion
 # =======
 #
 # Morphological ``erosion`` sets a pixel at (i, j) to the *minimum over all
 # pixels in the neighborhood centered at (i, j)*. The structuring element,
-# ``selem``, passed to ``erosion`` is a boolean array that describes this
+# ``footprint``, passed to ``erosion`` is a boolean array that describes this
 # neighborhood. Below, we use ``disk`` to create a circular structuring
 # element, which we use for most of the following examples.
 
-from skimage.morphology import erosion, dilation, opening, closing, white_tophat
-from skimage.morphology import black_tophat, skeletonize, convex_hull_image
-from skimage.morphology import disk
+from skimage.morphology import (erosion, dilation, opening, closing,  # noqa
+                                white_tophat)
+from skimage.morphology import black_tophat, skeletonize, convex_hull_image  # noqa
+from skimage.morphology import disk  # noqa
 
-selem = disk(6)
-eroded = erosion(orig_phantom, selem)
+footprint = disk(6)
+eroded = erosion(orig_phantom, footprint)
 plot_comparison(orig_phantom, eroded, 'erosion')
 
 ######################################################################
 # Notice how the white boundary of the image disappears or gets eroded as we
 # increase the size of the disk. Also notice the increase in size of the two
-# black ellipses in the center and the disappearance of the 3 light grey
+# black ellipses in the center and the disappearance of the 3 light gray
 # patches in the lower part of the image.
 #
-#Dilation
-#========
+# Dilation
+# ========
 #
-#Morphological ``dilation`` sets a pixel at (i, j) to the *maximum over all
-#pixels in the neighborhood centered at (i, j)*. Dilation enlarges bright
-#regions and shrinks dark regions.
+# Morphological ``dilation`` sets a pixel at (i, j) to the *maximum over all
+# pixels in the neighborhood centered at (i, j)*. Dilation enlarges bright
+# regions and shrinks dark regions.
 
-dilated = dilation(orig_phantom, selem)
+dilated = dilation(orig_phantom, footprint)
 plot_comparison(orig_phantom, dilated, 'dilation')
 
 ######################################################################
 # Notice how the white boundary of the image thickens, or gets dilated, as we
-#increase the size of the disk. Also notice the decrease in size of the two
-#black ellipses in the centre, and the thickening of the light grey circle
-#in the center and the 3 patches in the lower part of the image.
+# increase the size of the disk. Also notice the decrease in size of the two
+# black ellipses in the center, and the thickening of the light gray circle
+# in the center and the 3 patches in the lower part of the image.
 #
-#Opening
-#=======
+# Opening
+# =======
 #
-#Morphological ``opening`` on an image is defined as an *erosion followed by
-#a dilation*. Opening can remove small bright spots (i.e. "salt") and
-#connect small dark cracks.
+# Morphological ``opening`` on an image is defined as an *erosion followed by
+# a dilation*. Opening can remove small bright spots (i.e. "salt") and
+# connect small dark cracks.
 
-opened = opening(orig_phantom, selem)
+opened = opening(orig_phantom, footprint)
 plot_comparison(orig_phantom, opened, 'opening')
 
 ######################################################################
-#Since ``opening`` an image starts with an erosion operation, light regions
-#that are *smaller* than the structuring element are removed. The dilation
-#operation that follows ensures that light regions that are *larger* than
-#the structuring element retain their original size. Notice how the light
-#and dark shapes in the center their original thickness but the 3 lighter
-#patches in the bottom get completely eroded. The size dependence is
-#highlighted by the outer white ring: The parts of the ring thinner than the
-#structuring element were completely erased, while the thicker region at the
-#top retains its original thickness.
+# Since ``opening`` an image starts with an erosion operation, light regions
+# that are *smaller* than the structuring element are removed. The dilation
+# operation that follows ensures that light regions that are *larger* than
+# the structuring element retain their original size. Notice how the light
+# and dark shapes in the center their original thickness but the 3 lighter
+# patches in the bottom get completely eroded. The size dependence is
+# highlighted by the outer white ring: The parts of the ring thinner than the
+# structuring element were completely erased, while the thicker region at the
+# top retains its original thickness.
 #
-#Closing
-#=======
+# Closing
+# =======
 #
-#Morphological ``closing`` on an image is defined as a *dilation followed by
-#an erosion*. Closing can remove small dark spots (i.e. "pepper") and
-#connect small bright cracks.
+# Morphological ``closing`` on an image is defined as a *dilation followed by
+# an erosion*. Closing can remove small dark spots (i.e. "pepper") and
+# connect small bright cracks.
 #
-#To illustrate this more clearly, let's add a small crack to the white
-#border:
+# To illustrate this more clearly, let's add a small crack to the white
+# border:
 
 phantom = orig_phantom.copy()
 phantom[10:30, 200:210] = 0
 
-closed = closing(phantom, selem)
+closed = closing(phantom, footprint)
 plot_comparison(phantom, closed, 'closing')
 
 ######################################################################
@@ -148,7 +149,7 @@ phantom = orig_phantom.copy()
 phantom[340:350, 200:210] = 255
 phantom[100:110, 200:210] = 0
 
-w_tophat = white_tophat(phantom, selem)
+w_tophat = white_tophat(phantom, footprint)
 plot_comparison(phantom, w_tophat, 'white tophat')
 
 ######################################################################
@@ -164,30 +165,30 @@ plot_comparison(phantom, w_tophat, 'white tophat')
 # minus the original image**. This operation returns the *dark spots of the
 # image that are smaller than the structuring element*.
 
-b_tophat = black_tophat(phantom, selem)
+b_tophat = black_tophat(phantom, footprint)
 plot_comparison(phantom, b_tophat, 'black tophat')
 
 ######################################################################
-#As you can see, the 10-pixel wide black square is highlighted since
-#it is smaller than the structuring element.
+# As you can see, the 10-pixel wide black square is highlighted since
+# it is smaller than the structuring element.
 #
-#**Duality**
+# **Duality**
 #
-#As you should have noticed, many of these operations are simply the reverse
-#of another operation. This duality can be summarized as follows:
+# As you should have noticed, many of these operations are simply the reverse
+# of another operation. This duality can be summarized as follows:
 #
-# 1. Erosion <-> Dilation
+#   1. Erosion <-> Dilation
 #
-# 2. Opening <-> Closing
+#   2. Opening <-> Closing
 #
-# 3. White tophat <-> Black tophat
+#   3. White tophat <-> Black tophat
 #
-#Skeletonize
-#===========
+# Skeletonize
+# ===========
 #
-#Thinning is used to reduce each connected component in a binary image to a
-#*single-pixel wide skeleton*. It is important to note that this is
-#performed on binary images only.
+# Thinning is used to reduce each connected component in a binary image to a
+# *single-pixel wide skeleton*. It is important to note that this is
+# performed on binary images only.
 
 horse = data.horse()
 
@@ -195,7 +196,6 @@ sk = skeletonize(horse == 0)
 plot_comparison(horse, sk, 'skeletonize')
 
 ######################################################################
-#
 # As the name suggests, this technique is used to thin the image to 1-pixel
 # wide skeleton by applying thinning successively.
 #
@@ -216,8 +216,6 @@ plot_comparison(horse, hull1, 'convex hull')
 # If we add a small grain to the image, we can see how the convex hull adapts
 # to enclose that grain:
 
-import numpy as np
-
 horse_mask = horse == 0
 horse_mask[45:50, 75:80] = 1
 
@@ -225,7 +223,6 @@ hull2 = convex_hull_image(horse_mask)
 plot_comparison(horse_mask, hull2, 'convex hull')
 
 ######################################################################
-#
 # Additional Resources
 # ====================
 #
