@@ -19,7 +19,6 @@ from mpl_toolkits.mplot3d import Axes3D
 
 import numpy as np
 from skimage import exposure, util
-import imageio as io
 
 
 # Prepare data and apply histogram equalization
@@ -51,14 +50,14 @@ clip_limit = 0.9
 
 # Perform histogram equalization
 im_orig_he, im_degraded_he = \
-    [exposure.equalize_hist(im)
-     for im in [im_orig, im_degraded]]
+    (exposure.equalize_hist(im)
+     for im in [im_orig, im_degraded])
 
 im_orig_ahe, im_degraded_ahe = \
-    [exposure.equalize_adapthist(im,
+    (exposure.equalize_adapthist(im,
                                  kernel_size=kernel_size,
                                  clip_limit=clip_limit)
-     for im in [im_orig, im_degraded]]
+     for im in [im_orig, im_degraded])
 
 
 # Define functions to help plot the data
@@ -167,7 +166,7 @@ axs[3].scatter(xs=np.arange(len(sigmoid)),
                c=scalars_to_rgba(sigmoid,
                                  cmap=cmap, vmin=0, vmax=1, alpha=1.)[:, :3])
 
-# Subplot aesthetics (optimized for matplotlib 3.3)
+# Subplot aesthetics
 for iax, ax in enumerate(axs[:]):
 
     # Get rid of panes and axis lines
