@@ -88,7 +88,7 @@ from skimage import data, exposure
 image = data.astronaut()
 
 fd, hog_image = hog(image, orientations=8, pixels_per_cell=(16, 16),
-                    cells_per_block=(1, 1), visualize=True, multichannel=True)
+                    cells_per_block=(1, 1), visualize=True, channel_axis=-1)
 
 fig, (ax1, ax2) = plt.subplots(1, 2, figsize=(8, 4), sharex=True, sharey=True)
 
