@@ -4,14 +4,14 @@ Region Boundary based RAGs
 ==========================
 
 Construct a region boundary RAG with the ``rag_boundary`` function. The
-function  :py:func:`skimage.future.graph.rag_boundary` takes an
+function  :py:func:`skimage.graph.rag_boundary` takes an
 ``edge_map`` argument, which gives the significance of a feature (such as
 edges) being present at each pixel. In a region boundary RAG, the edge weight
 between two regions is the average value of the corresponding pixels in
 ``edge_map`` along their shared boundary.
 
 """
-from skimage.future import graph
+from skimage import graph
 from skimage import data, segmentation, color, filters, io
 from matplotlib import pyplot as plt
 
