@@ -9,7 +9,7 @@ difference in mean color. We then join regions with similar mean color.
 """
 
 from skimage import data, segmentation, color
-from skimage.future import graph
+from skimage import graph
 from matplotlib import pyplot as plt
 
 
