@@ -41,10 +41,10 @@ ax.imshow(image, cmap=plt.cm.gray)
 for props in regions:
     y0, x0 = props.centroid
     orientation = props.orientation
-    x1 = x0 + math.cos(orientation) * 0.5 * props.minor_axis_length
-    y1 = y0 - math.sin(orientation) * 0.5 * props.minor_axis_length
-    x2 = x0 - math.sin(orientation) * 0.5 * props.major_axis_length
-    y2 = y0 - math.cos(orientation) * 0.5 * props.major_axis_length
+    x1 = x0 + math.cos(orientation) * 0.5 * props.axis_minor_length
+    y1 = y0 - math.sin(orientation) * 0.5 * props.axis_minor_length
+    x2 = x0 - math.sin(orientation) * 0.5 * props.axis_major_length
+    y2 = y0 - math.cos(orientation) * 0.5 * props.axis_major_length
 
     ax.plot((x0, x1), (y0, y1), '-r', linewidth=2.5)
     ax.plot((x0, x2), (y0, y2), '-r', linewidth=2.5)
@@ -59,7 +59,7 @@ ax.axis((0, 600, 600, 0))
 plt.show()
 
 #####################################################################
-# We use the :py:func:`skimage.measure.regionprops_table` to compute
+# We use the :py:func:`skimage.measure.regionprops_table` function to compute
 # (selected) properties for each region. Note that
 # ``skimage.measure.regionprops_table`` actually computes the properties,
 # whereas ``skimage.measure.regionprops`` computes them when they come in use
@@ -67,8 +67,8 @@ plt.show()
 
 props = regionprops_table(label_img, properties=('centroid',
                                                  'orientation',
-                                                 'major_axis_length',
-                                                 'minor_axis_length'))
+                                                 'axis_major_length',
+                                                 'axis_minor_length'))
 
 #####################################################################
 # We now display a table of these selected properties (one region per row),
@@ -83,6 +83,7 @@ pd.DataFrame(props)
 # This example uses plotly in order to display properties when
 # hovering over the objects.
 
+import plotly
 import plotly.express as px
 import plotly.graph_objects as go
 from skimage import data, filters, measure, morphology
@@ -99,20 +100,20 @@ fig = px.imshow(img, binary_string=True)
 fig.update_traces(hoverinfo='skip') # hover is only for label info
 
 props = measure.regionprops(labels, img)
-properties = ['area', 'eccentricity', 'perimeter', 'mean_intensity']
+properties = ['area', 'eccentricity', 'perimeter', 'intensity_mean']
 
 # For each label, add a filled scatter trace for its contour,
 # and display the properties of the label in the hover of this trace.
 for index in range(1, labels.max()):
-    label = props[index].label
-    contour = measure.find_contours(labels == label, 0.5)[0]
+    label_i = props[index].label
+    contour = measure.find_contours(labels == label_i, 0.5)[0]
     y, x = contour.T
     hoverinfo = ''
     for prop_name in properties:
         hoverinfo += f'<b>{prop_name}: {getattr(props[index], prop_name):.2f}</b><br>'
     fig.add_trace(go.Scatter(
-        x=x, y=y, name=label,
+        x=x, y=y, name=label_i,
         mode='lines', fill='toself', showlegend=False,
         hovertemplate=hoverinfo, hoveron='points+fills'))
 
-fig
+plotly.io.show(fig)
