@@ -9,7 +9,7 @@ Thresholding is used to create a binary image from a grayscale image [1]_.
 
 .. seealso::
     A more comprehensive presentation on
-    :ref:`sphx_glr_auto_examples_applications_plot_thresholding.py`
+    :ref:`sphx_glr_auto_examples_applications_plot_thresholding_guide.py`
 
 """
 
