@@ -27,7 +27,7 @@ from types import BuiltinFunctionType, FunctionType, ModuleType
 DEBUG = True
 
 
-class ApiDocWriter(object):
+class ApiDocWriter:
     ''' Class for automatic detection and parsing of API docs
     to Sphinx-parsable reST format'''
 
@@ -179,9 +179,9 @@ class ApiDocWriter(object):
             print(filename, 'erk')
             # nothing that we could handle here.
             return ([],[])
-        f = open(filename, 'rt')
-        functions, classes = self._parse_lines(f)
-        f.close()
+        with open(filename) as f:
+            functions, classes = self._parse_lines(f)
+
         return functions, classes
 
     def _parse_module_with_import(self, uri):
@@ -273,23 +273,16 @@ class ApiDocWriter(object):
         classes = sorted(classes)
         submodules = sorted(submodules)
 
-        # Make a shorter version of the uri that omits the package name for
-        # titles
-        uri_short = re.sub(r'^%s\.' % self.package_name,'',uri)
-
         ad = '.. AUTO-GENERATED FILE -- DO NOT EDIT!\n\n'
 
         # Set the chapter title to read 'module' for all modules except for the
         # main packages
-        if '.' in uri:
-            title = 'Module: :mod:`' + uri_short + '`'
-        else:
-            title = ':mod:`' + uri_short + '`'
-        ad += title + '\n' + self.rst_section_levels[1] * len(title)
+        title = ':mod:`' + uri + '`'
+        ad += title + '\n' + self.rst_section_levels[1] * len(title) + '\n\n'
 
-        ad += '\n.. automodule:: ' + uri + '\n'
-        ad += '\n.. currentmodule:: ' + uri + '\n'
-        ad += '.. autosummary::\n\n'
+        ad += '.. automodule:: ' + uri + '\n\n'
+        ad += '.. currentmodule:: ' + uri + '\n\n'
+        ad += '.. autosummary::\n   :nosignatures:\n\n'
         for f in functions:
             ad += '   ' + uri + '.' + f + '\n'
         ad += '\n'
@@ -301,25 +294,22 @@ class ApiDocWriter(object):
         ad += '\n'
 
         for f in functions:
+            ad += "------------\n\n"
             # must NOT exclude from index to keep cross-refs working
             full_f = uri + '.' + f
-            ad += f + '\n'
-            ad += self.rst_section_levels[2] * len(f) + '\n'
             ad += '\n.. autofunction:: ' + full_f + '\n\n'
-            ad += '\n.. include:: ' + full_f + '.examples\n\n'
+            ad += f'    .. minigallery:: {full_f}\n\n'
         for c in classes:
-            ad += '\n:class:`' + c + '`\n' \
-                  + self.rst_section_levels[2] * \
-                  (len(c)+9) + '\n\n'
             ad += '\n.. autoclass:: ' + c + '\n'
             # must NOT exclude from index to keep cross-refs working
             ad += '  :members:\n' \
+                  '  :inherited-members:\n' \
                   '  :undoc-members:\n' \
                   '  :show-inheritance:\n' \
                   '\n' \
-                  '  .. automethod:: __init__\n'
+                  '  .. automethod:: __init__\n\n'
             full_c = uri + '.' + c
-            ad += '\n.. include:: ' + full_c + '.examples\n\n'
+            ad += f'    .. minigallery:: {full_c}\n\n'
         return ad
 
     def _survives_exclude(self, matchstr, match_type):
@@ -348,8 +338,7 @@ class ApiDocWriter(object):
         elif match_type == 'package':
             patterns = self.package_skip_patterns
         else:
-            raise ValueError('Cannot interpret match type "%s"'
-                             % match_type)
+            raise ValueError(f'Cannot interpret match type "{match_type}"')
         # Match to URI without package name
         L = len(self.package_name)
         if matchstr[:L] == self.package_name:
@@ -414,9 +403,8 @@ class ApiDocWriter(object):
             # write out to file
             outfile = os.path.join(outdir,
                                    m + self.rst_extension)
-            fileobj = open(outfile, 'wt')
-            fileobj.write(api_str)
-            fileobj.close()
+            with open(outfile, 'w') as fileobj:
+                fileobj.write(api_str)
             written_modules.append(m)
         self.written_modules = written_modules
 
@@ -469,40 +457,25 @@ class ApiDocWriter(object):
         else:
             relpath = outdir
         print("outdir: ", relpath)
-        idx = open(path,'wt')
-        w = idx.write
-        w('.. AUTO-GENERATED FILE -- DO NOT EDIT!\n\n')
+        with open(path, 'w') as idx:
+            w = idx.write
+            w('.. AUTO-GENERATED FILE -- DO NOT EDIT!\n\n')
 
-        # We look at the module name.  If it is `skimage`, display, if `skimage.submodule`, only show `submodule`,
-        # if it is `skimage.submodule.subsubmodule`, ignore.
+            # We look at the module name.
+            # If it is `skimage`, display,
+            # if `skimage.submodule`, only show `submodule`,
+            # if it is `skimage.submodule.subsubmodule`, ignore.
 
-        title = "API Reference for skimage |version|"
-        w(title + "\n")
-        w("=" * len(title) + "\n\n")
+            title = "API reference"
+            w(title + "\n")
+            w("=" * len(title) + "\n\n")
 
-        subtitle = "Submodules"
-        w(subtitle + "\n")
-        w("-" * len(subtitle) + "\n\n")
+            w('.. toctree::\n')
+            w('   :maxdepth: 1\n\n')
+            for f in self.written_modules:
+                w(f'   {os.path.join(relpath, f)}\n\n')
 
-        for f in self.written_modules:
-            module_name = f.split('.')
-            if len(module_name) > 2:
-                continue
-            elif len(module_name) == 1:
-                module_name = module_name[0]
-                prefix = "-"
-            elif len(module_name) == 2:
-                module_name = module_name[1]
-                prefix = "\n  -"
-            w(f'{prefix} `{module_name} <{os.path.join(f)}.html>`__\n')
-        w('\n')
-
-        subtitle = "Submodule Contents"
-        w(subtitle + "\n")
-        w("-" * len(subtitle) + "\n\n")
-
-        w('.. toctree::\n')
-        w('   :maxdepth: 2\n\n')
-        for f in self.written_modules:
-            w('   %s\n' % os.path.join(relpath,f))
-        idx.close()
+            w('----------------------\n\n')
+            w('.. toctree::\n')
+            w('   :maxdepth: 1\n\n')
+            w('   ../license\n')
