@@ -20,10 +20,23 @@ https://en.wikipedia.org/wiki/Color_difference
 
 import numpy as np
 
+from .._shared.utils import _supported_float_type
 from .colorconv import lab2lch, _cart2polar_2pi
 
 
-def deltaE_cie76(lab1, lab2):
+def _float_inputs(lab1, lab2, allow_float32=True):
+    lab1 = np.asarray(lab1)
+    lab2 = np.asarray(lab2)
+    if allow_float32:
+        float_dtype = _supported_float_type((lab1.dtype, lab2.dtype))
+    else:
+        float_dtype = np.float64
+    lab1 = lab1.astype(float_dtype, copy=False)
+    lab2 = lab2.astype(float_dtype, copy=False)
+    return lab1, lab2
+
+
+def deltaE_cie76(lab1, lab2, channel_axis=-1):
     """Euclidean distance between two points in Lab color space
 
     Parameters
@@ -32,6 +45,12 @@ def deltaE_cie76(lab1, lab2):
         reference color (Lab colorspace)
     lab2 : array_like
         comparison color (Lab colorspace)
+    channel_axis : int, optional
+        This parameter indicates which axis of the arrays corresponds to
+        channels.
+
+        .. versionadded:: 0.19
+           ``channel_axis`` was added in 0.19.
 
     Returns
     -------
@@ -44,14 +63,14 @@ def deltaE_cie76(lab1, lab2):
     .. [2] A. R. Robertson, "The CIE 1976 color-difference formulae,"
            Color Res. Appl. 2, 7-11 (1977).
     """
-    lab1 = np.asarray(lab1)
-    lab2 = np.asarray(lab2)
-    L1, a1, b1 = np.rollaxis(lab1, -1)[:3]
-    L2, a2, b2 = np.rollaxis(lab2, -1)[:3]
+    lab1, lab2 = _float_inputs(lab1, lab2, allow_float32=True)
+    L1, a1, b1 = np.moveaxis(lab1, source=channel_axis, destination=0)[:3]
+    L2, a2, b2 = np.moveaxis(lab2, source=channel_axis, destination=0)[:3]
     return np.sqrt((L2 - L1) ** 2 + (a2 - a1) ** 2 + (b2 - b1) ** 2)
 
 
-def deltaE_ciede94(lab1, lab2, kH=1, kC=1, kL=1, k1=0.045, k2=0.015):
+def deltaE_ciede94(lab1, lab2, kH=1, kC=1, kL=1, k1=0.045, k2=0.015, *,
+                   channel_axis=-1):
     """Color difference according to CIEDE 94 standard
 
     Accommodates perceptual non-uniformities through the use of application
@@ -73,6 +92,12 @@ def deltaE_ciede94(lab1, lab2, kH=1, kC=1, kL=1, k1=0.045, k2=0.015):
         first scale parameter
     k2 : float, optional
         second scale parameter
+    channel_axis : int, optional
+        This parameter indicates which axis of the arrays corresponds to
+        channels.
+
+        .. versionadded:: 0.19
+           ``channel_axis`` was added in 0.19.
 
     Returns
     -------
@@ -102,12 +127,16 @@ def deltaE_ciede94(lab1, lab2, kH=1, kC=1, kL=1, k1=0.045, k2=0.015):
     .. [1] https://en.wikipedia.org/wiki/Color_difference
     .. [2] http://www.brucelindbloom.com/index.html?Eqn_DeltaE_CIE94.html
     """
-    L1, C1 = np.rollaxis(lab2lch(lab1), -1)[:2]
-    L2, C2 = np.rollaxis(lab2lch(lab2), -1)[:2]
+    lab1, lab2 = _float_inputs(lab1, lab2, allow_float32=True)
+    lab1 = np.moveaxis(lab1, source=channel_axis, destination=0)
+    lab2 = np.moveaxis(lab2, source=channel_axis, destination=0)
+
+    L1, C1 = lab2lch(lab1, channel_axis=0)[:2]
+    L2, C2 = lab2lch(lab2, channel_axis=0)[:2]
 
     dL = L1 - L2
     dC = C1 - C2
-    dH2 = get_dH2(lab1, lab2)
+    dH2 = get_dH2(lab1, lab2, channel_axis=0)
 
     SL = 1
     SC = 1 + k1 * C1
@@ -119,7 +148,7 @@ def deltaE_ciede94(lab1, lab2, kH=1, kC=1, kL=1, k1=0.045, k2=0.015):
     return np.sqrt(np.maximum(dE2, 0))
 
 
-def deltaE_ciede2000(lab1, lab2, kL=1, kC=1, kH=1):
+def deltaE_ciede2000(lab1, lab2, kL=1, kC=1, kH=1, *, channel_axis=-1):
     """Color difference as given by the CIEDE 2000 standard.
 
     CIEDE 2000 is a major revision of CIDE94.  The perceptual calibration is
@@ -138,6 +167,12 @@ def deltaE_ciede2000(lab1, lab2, kL=1, kC=1, kH=1):
         chroma scale factor, usually 1
     kH : float (range), optional
         hue scale factor, usually 1
+    channel_axis : int, optional
+        This parameter indicates which axis of the arrays corresponds to
+        channels.
+
+        .. versionadded:: 0.19
+           ``channel_axis`` was added in 0.19.
 
     Returns
     -------
@@ -158,8 +193,9 @@ def deltaE_ciede2000(lab1, lab2, kL=1, kC=1, kH=1):
            color metrics tested with an accurate color-difference tolerance
            dataset," Appl. Opt. 33, 8069-8077 (1994).
     """
-    lab1 = np.asarray(lab1)
-    lab2 = np.asarray(lab2)
+    lab1, lab2 = _float_inputs(lab1, lab2, allow_float32=True)
+
+    channel_axis = channel_axis % lab1.ndim
     unroll = False
     if lab1.ndim == 1 and lab2.ndim == 1:
         unroll = True
@@ -167,12 +203,14 @@ def deltaE_ciede2000(lab1, lab2, kL=1, kC=1, kH=1):
             lab1 = lab1[None, :]
         if lab2.ndim == 1:
             lab2 = lab2[None, :]
-    L1, a1, b1 = np.rollaxis(lab1, -1)[:3]
-    L2, a2, b2 = np.rollaxis(lab2, -1)[:3]
+        channel_axis += 1
+    L1, a1, b1 = np.moveaxis(lab1, source=channel_axis, destination=0)[:3]
+    L2, a2, b2 = np.moveaxis(lab2, source=channel_axis, destination=0)[:3]
+
 
     # distort `a` based on average chroma
-    # then convert to lch coordines from distorted `a`
-    # all subsequence calculations are in the new coordiantes
+    # then convert to lch coordinates from distorted `a`
+    # all subsequence calculations are in the new coordinates
     # (often denoted "prime" in the literature)
     Cbar = 0.5 * (np.hypot(a1, b1) + np.hypot(a2, b2))
     c7 = Cbar ** 7
@@ -180,7 +218,7 @@ def deltaE_ciede2000(lab1, lab2, kL=1, kC=1, kH=1):
     scale = 1 + G
     C1, h1 = _cart2polar_2pi(a1 * scale, b1)
     C2, h2 = _cart2polar_2pi(a2 * scale, b2)
-    # recall that c, h are polar coordiantes.  c==r, h==theta
+    # recall that c, h are polar coordinates.  c==r, h==theta
 
     # cide2000 has four terms to delta_e:
     # 1) Luminance term
@@ -195,7 +233,7 @@ def deltaE_ciede2000(lab1, lab2, kL=1, kC=1, kH=1):
     L_term = (L2 - L1) / (kL * SL)
 
     # chroma term
-    Cbar = 0.5 * (C1 + C2)  # new coordiantes
+    Cbar = 0.5 * (C1 + C2)  # new coordinates
     SC = 1 + 0.045 * Cbar
     C_term = (C2 - C1) / (kC * SC)
 
@@ -244,7 +282,7 @@ def deltaE_ciede2000(lab1, lab2, kL=1, kC=1, kH=1):
     return ans
 
 
-def deltaE_cmc(lab1, lab2, kL=1, kC=1):
+def deltaE_cmc(lab1, lab2, kL=1, kC=1, *, channel_axis=-1):
     """Color difference from the  CMC l:c standard.
 
     This color difference was developed by the Colour Measurement Committee
@@ -263,6 +301,12 @@ def deltaE_cmc(lab1, lab2, kL=1, kC=1):
         reference color (Lab colorspace)
     lab2 : array_like
         comparison color (Lab colorspace)
+    channel_axis : int, optional
+        This parameter indicates which axis of the arrays corresponds to
+        channels.
+
+        .. versionadded:: 0.19
+           ``channel_axis`` was added in 0.19.
 
     Returns
     -------
@@ -283,12 +327,15 @@ def deltaE_cmc(lab1, lab2, kL=1, kC=1):
            JPC79 colour-difference formula," J. Soc. Dyers Colour. 100, 128-132
            (1984).
     """
-    L1, C1, h1 = np.rollaxis(lab2lch(lab1), -1)[:3]
-    L2, C2, h2 = np.rollaxis(lab2lch(lab2), -1)[:3]
+    lab1, lab2 = _float_inputs(lab1, lab2, allow_float32=True)
+    lab1 = np.moveaxis(lab1, source=channel_axis, destination=0)
+    lab2 = np.moveaxis(lab2, source=channel_axis, destination=0)
+    L1, C1, h1 = lab2lch(lab1, channel_axis=0)[:3]
+    L2, C2, h2 = lab2lch(lab2, channel_axis=0)[:3]
 
     dC = C1 - C2
     dL = L1 - L2
-    dH2 = get_dH2(lab1, lab2)
+    dH2 = get_dH2(lab1, lab2, channel_axis=0)
 
     T = np.where(np.logical_and(np.rad2deg(h1) >= 164, np.rad2deg(h1) <= 345),
                  0.56 + 0.2 * np.abs(np.cos(h1 + np.deg2rad(168))),
@@ -308,7 +355,7 @@ def deltaE_cmc(lab1, lab2, kL=1, kC=1):
     return np.sqrt(np.maximum(dE2, 0))
 
 
-def get_dH2(lab1, lab2):
+def get_dH2(lab1, lab2, *, channel_axis=-1):
     """squared hue difference term occurring in deltaE_cmc and deltaE_ciede94
 
     Despite its name, "dH" is not a simple difference of hue values.  We avoid
@@ -326,15 +373,20 @@ def get_dH2(lab1, lab2):
     and then simplified to:
         2*|ab1|*|ab2| - 2*dot(ab1, ab2)
     """
-    lab1 = np.asarray(lab1)
-    lab2 = np.asarray(lab2)
+    # This function needs double precision internally for accuracy
+    input_is_float_32 = _supported_float_type((lab1.dtype, lab2.dtype)) == \
+        np.float32
+    lab1, lab2 = _float_inputs(lab1, lab2, allow_float32=False)
 
-    a1, b1 = np.rollaxis(lab1, -1)[1:3]
-    a2, b2 = np.rollaxis(lab2, -1)[1:3]
+    a1, b1 = np.moveaxis(lab1, source=channel_axis, destination=0)[1:3]
+    a2, b2 = np.moveaxis(lab2, source=channel_axis, destination=0)[1:3]
 
     # magnitude of (a, b) is the chroma
     C1 = np.hypot(a1, b1)
     C2 = np.hypot(a2, b2)
 
     term = (C1 * C2) - (a1 * a2 + b1 * b2)
-    return 2 * term
+    out = 2 * term
+    if input_is_float_32:
+        out = out.astype(np.float32)
+    return out
