@@ -1,8 +1,13 @@
 import numpy as np
 
+from .._shared.utils import deprecate_kwarg
+from .._shared.filters import gaussian
 
+
+@deprecate_kwarg({'seed': 'rng'}, deprecated_version='0.21',
+                 removed_version='0.23')
 def binary_blobs(length=512, blob_size_fraction=0.1, n_dim=2,
-                 volume_fraction=0.5, seed=None):
+                 volume_fraction=0.5, rng=None):
     """
     Generate synthetic binary image with several rounded blob-like objects.
 
@@ -18,9 +23,10 @@ def binary_blobs(length=512, blob_size_fraction=0.1, n_dim=2,
     volume_fraction : float, default 0.5
         Fraction of image pixels covered by the blobs (where the output is 1).
         Should be in [0, 1].
-    seed : int, optional
-        Seed to initialize the random number generator.
-        If `None`, a random seed from the operating system is used.
+    rng : {`numpy.random.Generator`, int}, optional
+        Pseudo-random number generator.
+        By default, a PCG64 generator is used (see :func:`numpy.random.default_rng`).
+        If `rng` is an int, it is used to seed the generator.
 
     Returns
     -------
@@ -30,7 +36,7 @@ def binary_blobs(length=512, blob_size_fraction=0.1, n_dim=2,
     Examples
     --------
     >>> from skimage import data
-    >>> data.binary_blobs(length=5, blob_size_fraction=0.2, seed=1)
+    >>> data.binary_blobs(length=5, blob_size_fraction=0.2)  # doctest: +SKIP
     array([[ True, False,  True,  True,  True],
            [ True,  True,  True, False,  True],
            [False,  True, False,  True,  True],
@@ -41,17 +47,16 @@ def binary_blobs(length=512, blob_size_fraction=0.1, n_dim=2,
     >>> blobs = data.binary_blobs(length=256, blob_size_fraction=0.05)
     >>> # Blobs cover a smaller volume fraction of the image
     >>> blobs = data.binary_blobs(length=256, volume_fraction=0.3)
-    """
-    # filters is quite an expensive import since it imports all of scipy.signal
-    # We lazy import here
-    from ..filters import gaussian
 
-    rs = np.random.RandomState(seed)
+    """
+
+    rs = np.random.default_rng(rng)
     shape = tuple([length] * n_dim)
     mask = np.zeros(shape)
     n_pts = max(int(1. / blob_size_fraction) ** n_dim, 1)
-    points = (length * rs.rand(n_dim, n_pts)).astype(int)
+    points = (length * rs.random((n_dim, n_pts))).astype(int)
     mask[tuple(indices for indices in points)] = 1
-    mask = gaussian(mask, sigma=0.25 * length * blob_size_fraction)
+    mask = gaussian(mask, sigma=0.25 * length * blob_size_fraction,
+                    preserve_range=False)
     threshold = np.percentile(mask, 100 * (1 - volume_fraction))
     return np.logical_not(mask < threshold)
