@@ -178,7 +178,7 @@ def _get_numpy_hist_range(image, source_range):
     elif source_range == 'dtype':
         hist_range = dtype_limits(image, clip_negative=False)
     else:
-        ValueError('Wrong value for the `source_range` argument')
+        raise ValueError(f'Incorrect value for `source_range` argument: {source_range}')
     return hist_range
 
 
@@ -336,7 +336,7 @@ def cumulative_distribution(image, nbins=256):
     >>> image = img_as_float(data.camera())
     >>> hi = exposure.histogram(image)
     >>> cdf = exposure.cumulative_distribution(image)
-    >>> np.alltrue(cdf[0] == np.cumsum(hi[0])/float(image.size))
+    >>> all(cdf[0] == np.cumsum(hi[0])/float(image.size))
     True
     """
     hist, bin_centers = histogram(image, nbins)
@@ -517,7 +517,7 @@ def rescale_intensity(image, in_range='image', out_range='dtype'):
     -----
     .. versionchanged:: 0.17
         The dtype of the output array has changed to match the input dtype, or
-        float if the output range is specified by a pair of floats.
+        float if the output range is specified by a pair of values.
 
     See Also
     --------
@@ -595,7 +595,7 @@ def rescale_intensity(image, in_range='image', out_range='dtype'):
 
     if imin != imax:
         image = (image - imin) / (imax - imin)
-        return np.asarray(image * (omax - omin) + omin, dtype=out_dtype)
+        return (image * (omax - omin) + omin).astype(out_dtype)
     else:
         return np.clip(image, omin, omax).astype(out_dtype)
 
@@ -612,8 +612,8 @@ def _adjust_gamma_u8(image, gamma, gain):
     """LUT based implementation of gamma adjustment.
 
     """
-    lut = (255 * gain * (np.linspace(0, 1, 256) ** gamma))
-    lut = np.minimum(lut, 255).astype('uint8')
+    lut = 255 * gain * (np.linspace(0, 1, 256) ** gamma)
+    lut = np.minimum(np.rint(lut), 255).astype('uint8')
     return lut[image]
 
 
