@@ -4,7 +4,7 @@ from ..feature.util import (FeatureDetector, DescriptorExtractor,
                             _mask_border_keypoints,
                             _prepare_grayscale_input_2D)
 
-from ..feature import (corner_fast, corner_orientations, corner_peaks,
+from .corner import (corner_fast, corner_orientations, corner_peaks,
                        corner_harris)
 from ..transform import pyramid_gaussian
 from .._shared.utils import check_nD
@@ -182,6 +182,10 @@ class ORB(FeatureDetector, DescriptorExtractor):
 
             octave_image = np.ascontiguousarray(pyramid[octave])
 
+            if np.squeeze(octave_image).ndim < 2:
+                # No further keypoints can be detected if the image is not really 2d
+                break
+
             keypoints, orientations, responses = self._detect_octave(
                 octave_image)
 
@@ -301,6 +305,10 @@ class ORB(FeatureDetector, DescriptorExtractor):
 
             octave_image = np.ascontiguousarray(pyramid[octave])
 
+            if np.squeeze(octave_image).ndim < 2:
+                # No further keypoints can be detected if the image is not really 2d
+                break
+
             keypoints, orientations, responses = self._detect_octave(
                 octave_image)
 
