@@ -1,8 +1,9 @@
 from warnings import warn
+
 import numpy as np
 import scipy.ndimage as ndi
+
 from .. import measure
-from .._shared.utils import remove_arg
 from .._shared.coord import ensure_spacing
 
 
@@ -14,10 +15,16 @@ def _get_high_intensity_peaks(image, mask, num_peaks, min_distance, p_norm):
     coord = np.nonzero(mask)
     intensities = image[coord]
     # Highest peak first
-    idx_maxsort = np.argsort(-intensities)
+    idx_maxsort = np.argsort(-intensities, kind="stable")
     coord = np.transpose(coord)[idx_maxsort]
 
-    coord = ensure_spacing(coord, spacing=min_distance, p_norm=p_norm)
+    if np.isfinite(num_peaks):
+        max_out = int(num_peaks)
+    else:
+        max_out = None
+
+    coord = ensure_spacing(coord, spacing=min_distance, p_norm=p_norm,
+                           max_out=max_out)
 
     if len(coord) > num_peaks:
         coord = coord[:num_peaks]
@@ -33,7 +40,7 @@ def _get_peak_mask(image, footprint, threshold, mask=None):
         return image > threshold
 
     image_max = ndi.maximum_filter(image, footprint=footprint,
-                                   mode='constant')
+                                   mode='nearest')
 
     out = image == image_max
 
@@ -110,12 +117,11 @@ def _get_excluded_border_width(image, min_distance, exclude_border):
     return border_width
 
 
-@remove_arg("indices", changed_version="0.20")
 def peak_local_max(image, min_distance=1, threshold_abs=None,
-                   threshold_rel=None, exclude_border=True, indices=True,
+                   threshold_rel=None, exclude_border=True,
                    num_peaks=np.inf, footprint=None, labels=None,
                    num_peaks_per_label=np.inf, p_norm=np.inf):
-    """Find peaks in an image as coordinate list or boolean mask.
+    """Find peaks in an image as coordinate list.
 
     Peaks are the local maxima in a region of `2 * min_distance + 1`
     (i.e. peaks are separated by at least `min_distance`).
@@ -136,11 +142,12 @@ def peak_local_max(image, min_distance=1, threshold_abs=None,
     min_distance : int, optional
         The minimal allowed distance separating peaks. To find the
         maximum number of peaks, use `min_distance=1`.
-    threshold_abs : float, optional
+    threshold_abs : float or None, optional
         Minimum intensity of peaks. By default, the absolute threshold is
         the minimum intensity of the image.
-    threshold_rel : float, optional
-        Minimum intensity of peaks, calculated as `max(image) * threshold_rel`.
+    threshold_rel : float or None, optional
+        Minimum intensity of peaks, calculated as
+        ``max(image) * threshold_rel``.
     exclude_border : int, tuple of ints, or bool, optional
         If positive integer, `exclude_border` excludes peaks from within
         `exclude_border`-pixels of the border of the image.
@@ -151,15 +158,6 @@ def peak_local_max(image, min_distance=1, threshold_abs=None,
         If True, takes the `min_distance` parameter as value.
         If zero or False, peaks are identified regardless of their distance
         from the border.
-    indices : bool, optional
-        If True, the output will be an array representing peak
-        coordinates. The coordinates are sorted according to peaks
-        values (Larger first). If False, the output will be a boolean
-        array shaped as `image.shape` with peaks present at True
-        elements. ``indices`` is deprecated and will be removed in
-        version 0.20. Default behavior will be to always return peak
-        coordinates. You can obtain a mask as shown in the example
-        below.
     num_peaks : int, optional
         Maximum number of peaks. When the number of peaks exceeds `num_peaks`,
         return `num_peaks` peaks based on highest peak intensity.
@@ -179,18 +177,15 @@ def peak_local_max(image, min_distance=1, threshold_abs=None,
 
     Returns
     -------
-    output : ndarray or ndarray of bools
-
-        * If `indices = True`  : (row, column, ...) coordinates of peaks.
-        * If `indices = False` : Boolean array shaped like `image`, with peaks
-          represented by True values.
+    output : ndarray
+        The coordinates of the peaks.
 
     Notes
     -----
     The peak local maximum function returns the coordinates of local peaks
-    (maxima) in an image. Internally, a maximum filter is used for finding local
-    maxima. This operation dilates the original image. After comparison of the
-    dilated and original image, this function returns the coordinates or a mask
+    (maxima) in an image. Internally, a maximum filter is used for finding
+    local maxima. This operation dilates the original image. After comparison
+    of the dilated and original images, this function returns the coordinates
     of the peaks where the dilated image equals the original image.
 
     See also
@@ -281,7 +276,7 @@ def peak_local_max(image, min_distance=1, threshold_abs=None,
             # Get roi mask
             label_mask = labels[roi] == label_idx + 1
             # Extract image roi
-            img_object = image[roi]
+            img_object = image[roi].copy()
             # Ensure masked values don't affect roi's local peaks
             img_object[np.logical_not(label_mask)] = bg_val
 
@@ -311,12 +306,7 @@ def peak_local_max(image, min_distance=1, threshold_abs=None,
                                                     min_distance,
                                                     p_norm)
 
-    if indices:
-        return coordinates
-    else:
-        out = np.zeros_like(image, dtype=bool)
-        out[tuple(coordinates.T)] = True
-        return out
+    return coordinates
 
 
 def _prominent_peaks(image, min_xdistance=1, min_ydistance=1,
@@ -368,25 +358,25 @@ def _prominent_peaks(image, min_xdistance=1, min_ydistance=1,
 
     # Sort the list of peaks by intensity, not left-right, so larger peaks
     # in Hough space cannot be arbitrarily suppressed by smaller neighbors
-    props = sorted(props, key=lambda x: x.max_intensity)[::-1]
+    props = sorted(props, key=lambda x: x.intensity_max)[::-1]
     coords = np.array([np.round(p.centroid) for p in props], dtype=int)
 
     img_peaks = []
     ycoords_peaks = []
     xcoords_peaks = []
 
-    # relative coordinate grid for local neighbourhood suppression
+    # relative coordinate grid for local neighborhood suppression
     ycoords_ext, xcoords_ext = np.mgrid[-min_ydistance:min_ydistance + 1,
                                         -min_xdistance:min_xdistance + 1]
 
     for ycoords_idx, xcoords_idx in coords:
         accum = img_max[ycoords_idx, xcoords_idx]
         if accum > threshold:
-            # absolute coordinate grid for local neighbourhood suppression
+            # absolute coordinate grid for local neighborhood suppression
             ycoords_nh = ycoords_idx + ycoords_ext
             xcoords_nh = xcoords_idx + xcoords_ext
 
-            # no reflection for distance neighbourhood
+            # no reflection for distance neighborhood
             ycoords_in = np.logical_and(ycoords_nh > 0, ycoords_nh < rows)
             ycoords_nh = ycoords_nh[ycoords_in]
             xcoords_nh = xcoords_nh[ycoords_in]
@@ -401,7 +391,7 @@ def _prominent_peaks(image, min_xdistance=1, min_ydistance=1,
             ycoords_nh[xcoords_high] = rows - ycoords_nh[xcoords_high]
             xcoords_nh[xcoords_high] -= cols
 
-            # suppress neighbourhood
+            # suppress neighborhood
             img_max[ycoords_nh, xcoords_nh] = 0
 
             # add current feature to peaks
