@@ -2,21 +2,18 @@ import numpy as np
 import pytest
 from numpy.testing import assert_almost_equal, assert_array_equal, assert_equal
 
-from skimage import data
-from skimage import img_as_float
-from skimage import draw
-from skimage._shared.utils import _supported_float_type
+from skimage import data, draw, img_as_float
 from skimage._shared._warnings import expected_warnings
-from skimage._shared.testing import test_parallel
+from skimage._shared.testing import run_in_parallel
+from skimage._shared.utils import _supported_float_type
 from skimage.color import rgb2gray
-from skimage.feature import (corner_moravec, corner_harris, corner_shi_tomasi,
-                             corner_subpix, peak_local_max, corner_peaks,
-                             corner_kitchen_rosenfeld, corner_foerstner,
-                             corner_fast, corner_orientations,
-                             structure_tensor, structure_tensor_eigvals,
-                             structure_tensor_eigenvalues,
-                             hessian_matrix, hessian_matrix_eigvals,
-                             hessian_matrix_det, shape_index)
+from skimage.feature import (corner_fast, corner_foerstner, corner_harris,
+                             corner_kitchen_rosenfeld, corner_moravec,
+                             corner_orientations, corner_peaks,
+                             corner_shi_tomasi, corner_subpix, hessian_matrix,
+                             hessian_matrix_det, hessian_matrix_eigvals,
+                             peak_local_max, shape_index, structure_tensor,
+                             structure_tensor_eigenvalues)
 from skimage.morphology import cube, octagon
 
 
@@ -89,12 +86,11 @@ def test_structure_tensor_3d_rc_only():
 def test_structure_tensor_orders():
     square = np.zeros((5, 5))
     square[2, 2] = 1
-    with expected_warnings(['the default order of the structure']):
-        A_elems_default = structure_tensor(square, sigma=0.1)
+    A_elems_default = structure_tensor(square, sigma=0.1)
     A_elems_xy = structure_tensor(square, sigma=0.1, order='xy')
     A_elems_rc = structure_tensor(square, sigma=0.1, order='rc')
-    assert_array_equal(A_elems_xy, A_elems_default)
-    assert_array_equal(A_elems_xy, A_elems_rc[::-1])
+    assert_array_equal(A_elems_rc, A_elems_default)
+    assert_array_equal(A_elems_xy, A_elems_default[::-1])
 
 
 @pytest.mark.parametrize('ndim', [2, 3])
@@ -116,14 +112,16 @@ def test_structure_tensor_sigma(ndim):
 def test_hessian_matrix(dtype):
     square = np.zeros((5, 5), dtype=dtype)
     square[2, 2] = 4
-    Hrr, Hrc, Hcc = hessian_matrix(square, sigma=0.1, order='rc')
+    Hrr, Hrc, Hcc = hessian_matrix(square, sigma=0.1, order='rc',
+                                   use_gaussian_derivatives=False)
+
     out_dtype = _supported_float_type(dtype)
     assert all(a.dtype == out_dtype for a in (Hrr, Hrc, Hcc))
-    assert_almost_equal(Hrr, np.array([[0, 0,  0, 0, 0],
+    assert_almost_equal(Hrr, np.array([[0, 0,  2, 0, 0],
                                        [0, 0,  0, 0, 0],
-                                       [2, 0, -2, 0, 2],
+                                       [0, 0, -2, 0, 0],
                                        [0, 0,  0, 0, 0],
-                                       [0, 0,  0, 0, 0]]))
+                                       [0, 0,  2, 0, 0]]))
 
     assert_almost_equal(Hrc, np.array([[0,  0, 0,  0, 0],
                                        [0,  1, 0, -1, 0],
@@ -131,24 +129,70 @@ def test_hessian_matrix(dtype):
                                        [0, -1, 0,  1, 0],
                                        [0,  0, 0,  0, 0]]))
 
-    assert_almost_equal(Hcc, np.array([[0, 0,  2, 0, 0],
+    assert_almost_equal(Hcc, np.array([[0, 0,  0, 0, 0],
                                        [0, 0,  0, 0, 0],
-                                       [0, 0, -2, 0, 0],
+                                       [2, 0, -2, 0, 2],
                                        [0, 0,  0, 0, 0],
-                                       [0, 0,  2, 0, 0]]))
+                                       [0, 0,  0, 0, 0]]))
+
+    with expected_warnings(["use_gaussian_derivatives currently defaults"]):
+        # FutureWarning warning when use_gaussian_derivatives is not
+        # specified.
+        hessian_matrix(square, sigma=0.1, order='rc')
+
+
+@pytest.mark.parametrize('use_gaussian_derivatives', [False, True])
+def test_hessian_matrix_order(use_gaussian_derivatives):
+    square = np.zeros((5, 5), dtype=float)
+    square[2, 2] = 4
+
+    Hxx, Hxy, Hyy = hessian_matrix(
+        square, sigma=0.1, order="xy",
+        use_gaussian_derivatives=use_gaussian_derivatives)
+
+    Hrr, Hrc, Hcc = hessian_matrix(
+        square, sigma=0.1, order="rc",
+        use_gaussian_derivatives=use_gaussian_derivatives)
+
+    # verify results are equivalent, just reversed in order
+    assert_array_equal(Hxx, Hcc)
+    assert_array_equal(Hxy, Hrc)
+    assert_array_equal(Hyy, Hrr)
 
 
 def test_hessian_matrix_3d():
     cube = np.zeros((5, 5, 5))
     cube[2, 2, 2] = 4
-    Hs = hessian_matrix(cube, sigma=0.1, order='rc')
-    assert len(Hs) == 6, ("incorrect number of Hessian images (%i) for 3D" %
-                          len(Hs))
+    Hs = hessian_matrix(cube, sigma=0.1, order='rc',
+                        use_gaussian_derivatives=False)
+    assert len(Hs) == 6, (f"incorrect number of Hessian images ({len(Hs)}) for 3D")
+    # This test didn't catch the fix in gh-6624 (passes with and without) ...
     assert_almost_equal(Hs[2][:, 2, :], np.array([[0,  0,  0,  0,  0],
                                                   [0,  1,  0, -1,  0],
                                                   [0,  0,  0,  0,  0],
                                                   [0, -1,  0,  1,  0],
                                                   [0,  0,  0,  0,  0]]))
+    # ... so we add another test that fails for the not-fixed hessian_matrix
+    assert_almost_equal(Hs[0][:, 2, :], np.array([[0,  0,  2,  0,  0],
+                                                  [0,  0,  0,  0,  0],
+                                                  [0,  0, -2,  0,  0],
+                                                  [0,  0,  0,  0,  0],
+                                                  [0,  0,  2,  0,  0]]))
+
+
+@pytest.mark.parametrize('use_gaussian_derivatives', [False, True])
+def test_hessian_matrix_3d_xy(use_gaussian_derivatives):
+
+    img = np.ones((5, 5, 5))
+
+    # order="xy" is only permitted for 2D
+    with pytest.raises(ValueError):
+        hessian_matrix(img, sigma=0.1, order="xy",
+                       use_gaussian_derivatives=use_gaussian_derivatives)
+
+    with pytest.raises(ValueError):
+        hessian_matrix(img, sigma=0.1, order='nonexistant',
+                       use_gaussian_derivatives=use_gaussian_derivatives)
 
 
 @pytest.mark.parametrize('dtype', [np.float16, np.float32, np.float64])
@@ -181,21 +225,12 @@ def test_structure_tensor_eigenvalues_3d():
     assert np.all(e0[boundary] != 0)
 
 
-def test_structure_tensor_eigvals():
-    square = np.zeros((5, 5))
-    square[2, 2] = 1
-    A_elems = structure_tensor(square, sigma=0.1, order='rc')
-    with expected_warnings(['structure_tensor_eigvals is deprecated']):
-        eigvals = structure_tensor_eigvals(*A_elems)
-    eigenvalues = structure_tensor_eigenvalues(A_elems)
-    assert_array_equal(eigvals, eigenvalues)
-
-
 @pytest.mark.parametrize('dtype', [np.float16, np.float32, np.float64])
 def test_hessian_matrix_eigvals(dtype):
     square = np.zeros((5, 5), dtype=dtype)
     square[2, 2] = 4
-    H = hessian_matrix(square, sigma=0.1, order='rc')
+    H = hessian_matrix(square, sigma=0.1, order='rc',
+                       use_gaussian_derivatives=False)
     l1, l2 = hessian_matrix_eigvals(H)
     out_dtype = _supported_float_type(dtype)
     assert all(a.dtype == out_dtype for a in (l1, l2))
@@ -214,7 +249,7 @@ def test_hessian_matrix_eigvals(dtype):
 @pytest.mark.parametrize('dtype', [np.float16, np.float32, np.float64])
 def test_hessian_matrix_eigvals_3d(im3d, dtype):
     im3d = im3d.astype(dtype, copy=False)
-    H = hessian_matrix(im3d)
+    H = hessian_matrix(im3d, use_gaussian_derivatives=False)
     E = hessian_matrix_eigvals(H)
     out_dtype = _supported_float_type(dtype)
     assert all(a.dtype == out_dtype for a in E)
@@ -236,7 +271,7 @@ def test_hessian_matrix_eigvals_3d(im3d, dtype):
     assert np.max(response0) > 0
 
 
-@test_parallel()
+@run_in_parallel()
 def test_hessian_matrix_det():
     image = np.zeros((5, 5))
     image[2, 2] = 1
@@ -280,7 +315,7 @@ def test_shape_index():
     )
 
 
-@test_parallel()
+@run_in_parallel()
 def test_square_image():
     im = np.zeros((50, 50)).astype(float)
     im[:25, :25] = 1.
@@ -337,8 +372,8 @@ def test_corner_foerstner_dtype(dtype):
 def test_noisy_square_image():
     im = np.zeros((50, 50)).astype(float)
     im[:25, :25] = 1.
-    np.random.seed(seed=1234)
-    im = im + np.random.uniform(size=im.shape) * .2
+    rng = np.random.default_rng(1234)
+    im = im + rng.uniform(size=im.shape) * .2
 
     # Moravec
     results = peak_local_max(corner_moravec(im),
@@ -434,7 +469,7 @@ def test_subpix_no_class():
     img[25, 25] = 1e-10
     corner = peak_local_max(corner_harris(img),
                             min_distance=10, threshold_rel=0, num_peaks=1)
-    subpix = corner_subpix(img, np.array([[25, 25]]))
+    subpix = corner_subpix(img, corner)
     assert_array_equal(subpix[0], (np.nan, np.nan))
 
 
@@ -513,7 +548,7 @@ def test_corner_fast_image_unsupported_error():
         corner_fast(img)
 
 
-@test_parallel()
+@run_in_parallel()
 def test_corner_fast_astronaut():
     img = rgb2gray(data.astronaut())
     expected = np.array([[444, 310],
@@ -574,7 +609,7 @@ def test_corner_orientations_even_shape_error():
             np.asarray([[7, 7]]), np.ones((4, 4)))
 
 
-@test_parallel()
+@run_in_parallel()
 def test_corner_orientations_astronaut():
     img = rgb2gray(data.astronaut())
     corners = corner_peaks(corner_fast(img, 11, 0.35),
