@@ -1,13 +1,11 @@
-import os
 import numpy as np
-from scipy import ndimage as ndi
-from skimage import color
-from skimage import data
-from skimage import feature
-from skimage import img_as_float
-from skimage import draw
-from skimage._shared.testing import assert_almost_equal, fetch
-from skimage._shared import testing
+import pytest
+from numpy.testing import assert_almost_equal
+
+from skimage import color, data, draw, feature, img_as_float
+from skimage._shared import filters
+from skimage._shared.testing import fetch
+from skimage._shared.utils import _supported_float_type
 
 
 def test_hog_output_size():
@@ -19,26 +17,34 @@ def test_hog_output_size():
     assert len(fd) == 9 * (256 // 8) * (512 // 8)
 
 
-def test_hog_output_correctness_l1_norm():
-    img = color.rgb2gray(data.astronaut())
+@pytest.mark.parametrize('dtype', [np.float32, np.float64])
+def test_hog_output_correctness_l1_norm(dtype):
+    img = color.rgb2gray(data.astronaut()).astype(dtype=dtype, copy=False)
     correct_output = np.load(fetch('data/astronaut_GRAY_hog_L1.npy'))
 
     output = feature.hog(img, orientations=9, pixels_per_cell=(8, 8),
                          cells_per_block=(3, 3), block_norm='L1',
                          feature_vector=True, transform_sqrt=False,
                          visualize=False)
-    assert_almost_equal(output, correct_output)
+    float_dtype = _supported_float_type(dtype)
+    assert output.dtype == float_dtype
+    decimal = 7 if float_dtype == np.float64 else 5
+    assert_almost_equal(output, correct_output, decimal=decimal)
 
 
-def test_hog_output_correctness_l2hys_norm():
-    img = color.rgb2gray(data.astronaut())
+@pytest.mark.parametrize('dtype', [np.float32, np.float64])
+def test_hog_output_correctness_l2hys_norm(dtype):
+    img = color.rgb2gray(data.astronaut()).astype(dtype=dtype, copy=False)
     correct_output = np.load(fetch('data/astronaut_GRAY_hog_L2-Hys.npy'))
 
     output = feature.hog(img, orientations=9, pixels_per_cell=(8, 8),
                          cells_per_block=(3, 3), block_norm='L2-Hys',
                          feature_vector=True, transform_sqrt=False,
                          visualize=False)
-    assert_almost_equal(output, correct_output)
+    float_dtype = _supported_float_type(dtype)
+    assert output.dtype == float_dtype
+    decimal = 7 if float_dtype == np.float64 else 5
+    assert_almost_equal(output, correct_output, decimal=decimal)
 
 
 def test_hog_image_size_cell_size_mismatch():
@@ -48,6 +54,20 @@ def test_hog_image_size_cell_size_mismatch():
     assert len(fd) == 9 * (150 // 8) * (200 // 8)
 
 
+def test_hog_odd_cell_size():
+    img = np.zeros((3, 3))
+    img[2, 2] = 1
+
+    correct_output = np.zeros((9, ))
+    correct_output[0] = 0.5
+    correct_output[4] = 0.5
+
+    output = feature.hog(img, pixels_per_cell=(3, 3),
+                         cells_per_block=(1, 1), block_norm='L1')
+
+    assert_almost_equal(output, correct_output, decimal=1)
+
+
 def test_hog_basic_orientations_and_data_types():
     # scenario:
     #  1) create image (with float values) where upper half is filled by
@@ -160,7 +180,7 @@ def test_hog_orientations_circle():
     image = np.zeros((height, width))
     rr, cc = draw.disk((int(height / 2), int(width / 2)), int(width / 3))
     image[rr, cc] = 100
-    image = ndi.gaussian_filter(image, 2)
+    image = filters.gaussian(image, 2, mode='reflect')
 
     for orientations in range(2, 15):
         (hog, hog_img) = feature.hog(image, orientations=orientations,
@@ -182,7 +202,7 @@ def test_hog_orientations_circle():
             plt.imshow(hog_img)
             plt.colorbar()
             plt.title('HOG result visualisation, '
-                      'orientations=%d' % (orientations))
+                      f'orientations={orientations}')
             plt.show()
 
         # reshape resulting feature vector to matrix with N columns (each
@@ -230,27 +250,40 @@ def test_hog_visualization_orientation():
 
 def test_hog_block_normalization_incorrect_error():
     img = np.eye(4)
-    with testing.raises(ValueError):
+    with pytest.raises(ValueError):
         feature.hog(img, block_norm='Linf')
 
 
-@testing.parametrize("shape,multichannel", [
-    ((3, 3, 3), False),
-    ((3, 3), True),
-    ((3, 3, 3, 3), True),
+@pytest.mark.parametrize("shape,channel_axis", [
+    ((3, 3, 3), None),
+    ((3, 3), -1),
+    ((3, 3, 3, 3), -1),
 ])
-def test_hog_incorrect_dimensions(shape, multichannel):
+def test_hog_incorrect_dimensions(shape, channel_axis):
     img = np.zeros(shape)
-    with testing.raises(ValueError):
-        feature.hog(img, multichannel=multichannel, block_norm='L1')
+    with pytest.raises(ValueError):
+        feature.hog(img, channel_axis=channel_axis, block_norm='L1')
 
 
-def test_hog_output_equivariance_multichannel():
+def test_hog_output_equivariance_deprecated_multichannel():
     img = data.astronaut()
     img[:, :, (1, 2)] = 0
-    hog_ref = feature.hog(img, multichannel=True, block_norm='L1')
+    hog_ref = feature.hog(img, channel_axis=-1, block_norm='L1')
 
     for n in (1, 2):
-        hog_fact = feature.hog(np.roll(img, n, axis=2), multichannel=True,
+        hog_fact = feature.hog(np.roll(img, n, axis=2), channel_axis=-1,
                                block_norm='L1')
         assert_almost_equal(hog_ref, hog_fact)
+
+
+@pytest.mark.parametrize('channel_axis', [0, 1, -1, -2])
+def test_hog_output_equivariance_channel_axis(channel_axis):
+    img = data.astronaut()[:64, :32]
+    img[:, :, (1, 2)] = 0
+    img = np.moveaxis(img, -1, channel_axis)
+    hog_ref = feature.hog(img, channel_axis=channel_axis, block_norm='L1')
+
+    for n in (1, 2):
+        hog_fact = feature.hog(np.roll(img, n, axis=channel_axis),
+                               channel_axis=channel_axis, block_norm='L1')
+        assert_almost_equal(hog_ref, hog_fact)
