@@ -1,26 +1,24 @@
 import itertools
+
 import numpy as np
 import pytest
-import unittest
-from skimage._shared._warnings import expected_warnings
-from skimage._shared.testing import assert_array_almost_equal
-from skimage._shared.testing import assert_equal
+from numpy.testing import (assert_array_almost_equal, assert_array_equal,
+                           assert_equal)
 from scipy import ndimage as ndi
+
+from skimage._shared._warnings import expected_warnings
 from skimage.feature import peak
 
 
 np.random.seed(21)
 
+
 class TestPeakLocalMax():
     def test_trivial_case(self):
         trivial = np.zeros((25, 25))
         peak_indices = peak.peak_local_max(trivial, min_distance=1)
         assert type(peak_indices) is np.ndarray
         assert peak_indices.size == 0
-        with expected_warnings(["indices argument is deprecated"]):
-            peaks = peak.peak_local_max(trivial, min_distance=1,
-                                        indices=False)
-        assert (peaks.astype(bool) == trivial).all()
 
     def test_noisy_peaks(self):
         peak_locations = [(7, 7), (7, 13), (13, 7), (13, 13)]
@@ -82,7 +80,8 @@ class TestPeakLocalMax():
         image[1, 5] = 12
         image[3, 5] = 8
         image[5, 3] = 7
-        assert len(peak.peak_local_max(image, min_distance=1, threshold_abs=0)) == 5
+        assert len(peak.peak_local_max(image, min_distance=1,
+                                       threshold_abs=0)) == 5
         peaks_limited = peak.peak_local_max(
             image, min_distance=1, threshold_abs=0, num_peaks=2)
         assert len(peaks_limited) == 2
@@ -111,7 +110,6 @@ class TestPeakLocalMax():
             image, min_distance=1, threshold_abs=0, labels=labels, num_peaks=2)
         assert len(peaks_limited) == 2
 
-
     def test_num_peaks_tot_vs_labels_4quadrants(self):
         np.random.seed(21)
         image = np.random.uniform(size=(20, 30))
@@ -133,12 +131,11 @@ class TestPeakLocalMax():
                                      num_peaks_per_label=2)
         assert len(result) == 2
 
-
     def test_num_peaks3D(self):
         # Issue 1354: the old code only hold for 2D arrays
         # and this code would die with IndexError
         image = np.zeros((10, 10, 100))
-        image[5,5,::5] = np.arange(20)
+        image[5, 5, ::5] = np.arange(20)
         peaks_limited = peak.peak_local_max(image, min_distance=1, num_peaks=2)
         assert len(peaks_limited) == 2
 
@@ -153,12 +150,13 @@ class TestPeakLocalMax():
         for imin, imax in ((0, 20), (20, 40)):
             for jmin, jmax in ((0, 30), (30, 60)):
                 expected[imin:imax, jmin:jmax] = ndi.maximum_filter(
-                                image[imin:imax, jmin:jmax], footprint=footprint)
+                    image[imin:imax, jmin:jmax], footprint=footprint)
         expected = (expected == image)
-        with expected_warnings(["indices argument is deprecated"]):
-            result = peak.peak_local_max(image, labels=labels, min_distance=1,
-                                         threshold_rel=0, footprint=footprint,
-                                         indices=False, exclude_border=False)
+        peak_idx = peak.peak_local_max(image, labels=labels, min_distance=1,
+                                       threshold_rel=0, footprint=footprint,
+                                       exclude_border=False)
+        result = np.zeros_like(expected, dtype=bool)
+        result[tuple(peak_idx.T)] = True
         assert (result == expected).all()
 
     def test_indices_with_labels(self):
@@ -180,63 +178,44 @@ class TestPeakLocalMax():
         result = result[np.argsort(image[tuple(result.T)])[::-1]]
         assert (result == expected).all()
 
-    def test_ndarray_indices_false(self):
-        nd_image = np.zeros((5, 5, 5))
-        nd_image[2, 2, 2] = 1
-        with expected_warnings(["indices argument is deprecated"]):
-            peaks = peak.peak_local_max(nd_image, min_distance=1,
-                                        indices=False)
-        assert (peaks == nd_image.astype(bool)).all()
-
     def test_ndarray_exclude_border(self):
         nd_image = np.zeros((5, 5, 5))
         nd_image[[1, 0, 0], [0, 1, 0], [0, 0, 1]] = 1
         nd_image[3, 0, 0] = 1
         nd_image[2, 2, 2] = 1
-        expected = np.zeros_like(nd_image, dtype=bool)
-        expected[2, 2, 2] = True
-        expectedNoBorder = np.zeros_like(nd_image, dtype=bool)
-        expectedNoBorder[2, 2, 2] = True
-        expectedNoBorder[0, 0, 1] = True
-        expectedNoBorder[3, 0, 0] = True
-        with expected_warnings(["indices argument is deprecated"]):
-            result = peak.peak_local_max(nd_image, min_distance=2,
-                                         exclude_border=2, indices=False)
-            assert_equal(result, expected)
-            # Check that bools work as expected
-            assert_equal(
-                peak.peak_local_max(nd_image, min_distance=2,
-                                    exclude_border=2, indices=False),
-                peak.peak_local_max(nd_image, min_distance=2,
-                                    exclude_border=True, indices=False)
-            )
-            assert_equal(
-                peak.peak_local_max(nd_image, min_distance=2,
-                                    exclude_border=0, indices=False),
-                peak.peak_local_max(nd_image, min_distance=2,
-                                    exclude_border=False, indices=False)
-            )
-            # Check both versions with  no border
-            assert_equal(
-                peak.peak_local_max(nd_image, min_distance=2,
-                                    exclude_border=0, indices=False),
-                expectedNoBorder,
-            )
-            assert_equal(
-                peak.peak_local_max(nd_image,
-                                    exclude_border=False, indices=False),
-                nd_image.astype(bool)
-            )
+        expected = np.array([[2, 2, 2]], dtype=int)
+        expectedNoBorder = np.array([[0, 0, 1], [2, 2, 2], [3, 0, 0]],
+                                    dtype=int)
+        result = peak.peak_local_max(nd_image, min_distance=2,
+                                     exclude_border=2)
+        assert_array_equal(result, expected)
+        # Check that bools work as expected
+        assert_array_equal(
+            peak.peak_local_max(nd_image, min_distance=2, exclude_border=2),
+            peak.peak_local_max(nd_image, min_distance=2, exclude_border=True)
+        )
+        assert_array_equal(
+            peak.peak_local_max(nd_image, min_distance=2, exclude_border=0),
+            peak.peak_local_max(nd_image, min_distance=2, exclude_border=False)
+        )
+
+        # Check both versions with no border
+        result = peak.peak_local_max(nd_image, min_distance=2,
+                                     exclude_border=0)
+        assert_array_equal(result, expectedNoBorder)
+        peak_idx = peak.peak_local_max(nd_image, exclude_border=False)
+        result = np.zeros_like(nd_image, dtype=bool)
+        result[tuple(peak_idx.T)] = True
+        assert_array_equal(result, nd_image.astype(bool))
 
     def test_empty(self):
         image = np.zeros((10, 20))
         labels = np.zeros((10, 20), int)
-        with expected_warnings(["indices argument is deprecated"]):
-            result = peak.peak_local_max(image, labels=labels,
-                                         footprint=np.ones((3, 3), bool),
-                                         min_distance=1, threshold_rel=0,
-                                         indices=False, exclude_border=False)
-        assert np.all(~ result)
+        result = peak.peak_local_max(image, labels=labels,
+                                     footprint=np.ones((3, 3), bool),
+                                     min_distance=1, threshold_rel=0,
+                                     exclude_border=False)
+        assert result.shape == (0, image.ndim)
 
     def test_empty_non2d_indices(self):
         image = np.zeros((10, 10, 10))
@@ -251,11 +230,12 @@ class TestPeakLocalMax():
         labels = np.zeros((10, 20), int)
         image[5, 5] = 1
         labels[5, 5] = 1
-        with expected_warnings(["indices argument is deprecated"]):
-            result = peak.peak_local_max(image, labels=labels,
-                                         footprint=np.ones((3, 3), bool),
-                                         min_distance=1, threshold_rel=0,
-                                         indices=False, exclude_border=False)
+        peak_idx = peak.peak_local_max(image, labels=labels,
+                                       footprint=np.ones((3, 3), bool),
+                                       min_distance=1, threshold_rel=0,
+                                       exclude_border=False)
+        result = np.zeros_like(image, dtype=bool)
+        result[tuple(peak_idx.T)] = True
         assert np.all(result == (labels == 1))
 
     def test_adjacent_and_same(self):
@@ -263,12 +243,12 @@ class TestPeakLocalMax():
         labels = np.zeros((10, 20), int)
         image[5, 5:6] = 1
         labels[5, 5:6] = 1
-        with expected_warnings(["indices argument is deprecated"]):
-            result = peak.peak_local_max(image, labels=labels,
-                                         footprint=np.ones((3, 3), bool),
-                                         min_distance=1, threshold_rel=0,
-                                         indices=False, exclude_border=False)
-        assert np.all(result == (labels == 1))
+        expected = np.stack(np.where(labels == 1), axis=-1)
+        result = peak.peak_local_max(image, labels=labels,
+                                     footprint=np.ones((3, 3), bool),
+                                     min_distance=1, threshold_rel=0,
+                                     exclude_border=False)
+        assert_array_equal(result, expected)
 
     def test_adjacent_and_different(self):
         image = np.zeros((10, 20))
@@ -276,18 +256,16 @@ class TestPeakLocalMax():
         image[5, 5] = 1
         image[5, 6] = .5
         labels[5, 5:6] = 1
-        expected = (image == 1)
-        with expected_warnings(["indices argument is deprecated"]):
-            result = peak.peak_local_max(image, labels=labels,
-                                         footprint=np.ones((3, 3), bool),
-                                         min_distance=1, threshold_rel=0,
-                                         indices=False, exclude_border=False)
-        assert np.all(result == expected)
-        with expected_warnings(["indices argument is deprecated"]):
-            result = peak.peak_local_max(image, labels=labels,
-                                         min_distance=1, threshold_rel=0,
-                                         indices=False, exclude_border=False)
-        assert np.all(result == expected)
+        expected = np.stack(np.where(image == 1), axis=-1)
+        result = peak.peak_local_max(image, labels=labels,
+                                     footprint=np.ones((3, 3), bool),
+                                     min_distance=1, threshold_rel=0,
+                                     exclude_border=False)
+        assert_array_equal(result, expected)
+        result = peak.peak_local_max(image, labels=labels,
+                                     min_distance=1, threshold_rel=0,
+                                     exclude_border=False)
+        assert_array_equal(result, expected)
 
     def test_not_adjacent_and_different(self):
         image = np.zeros((10, 20))
@@ -295,13 +273,12 @@ class TestPeakLocalMax():
         image[5, 5] = 1
         image[5, 8] = .5
         labels[image > 0] = 1
-        expected = (labels == 1)
-        with expected_warnings(["indices argument is deprecated"]):
-            result = peak.peak_local_max(image, labels=labels,
-                                         footprint=np.ones((3, 3), bool),
-                                         min_distance=1, threshold_rel=0,
-                                         indices=False, exclude_border=False)
-        assert np.all(result == expected)
+        expected = np.stack(np.where(labels == 1), axis=-1)
+        result = peak.peak_local_max(image, labels=labels,
+                                     footprint=np.ones((3, 3), bool),
+                                     min_distance=1, threshold_rel=0,
+                                     exclude_border=False)
+        assert_array_equal(result, expected)
 
     def test_two_objects(self):
         image = np.zeros((10, 20))
@@ -310,13 +287,12 @@ class TestPeakLocalMax():
         image[5, 15] = .5
         labels[5, 5] = 1
         labels[5, 15] = 2
-        expected = (labels > 0)
-        with expected_warnings(["indices argument is deprecated"]):
-            result = peak.peak_local_max(image, labels=labels,
-                                         footprint=np.ones((3, 3), bool),
-                                         min_distance=1, threshold_rel=0,
-                                         indices=False, exclude_border=False)
-        assert np.all(result == expected)
+        expected = np.stack(np.where(labels > 0), axis=-1)
+        result = peak.peak_local_max(image, labels=labels,
+                                     footprint=np.ones((3, 3), bool),
+                                     min_distance=1, threshold_rel=0,
+                                     exclude_border=False)
+        assert_array_equal(result, expected)
 
     def test_adjacent_different_objects(self):
         image = np.zeros((10, 20))
@@ -325,13 +301,12 @@ class TestPeakLocalMax():
         image[5, 6] = .5
         labels[5, 5] = 1
         labels[5, 6] = 2
-        expected = (labels > 0)
-        with expected_warnings(["indices argument is deprecated"]):
-            result = peak.peak_local_max(image, labels=labels,
-                                         footprint=np.ones((3, 3), bool),
-                                         min_distance=1, threshold_rel=0,
-                                         indices=False, exclude_border=False)
-        assert np.all(result == expected)
+        expected = np.stack(np.where(labels > 0), axis=-1)
+        result = peak.peak_local_max(image, labels=labels,
+                                     footprint=np.ones((3, 3), bool),
+                                     min_distance=1, threshold_rel=0,
+                                     exclude_border=False)
+        assert_array_equal(result, expected)
 
     def test_four_quadrants(self):
         image = np.random.uniform(size=(20, 30))
@@ -345,13 +320,13 @@ class TestPeakLocalMax():
                 expected[imin:imax, jmin:jmax] = ndi.maximum_filter(
                     image[imin:imax, jmin:jmax], footprint=footprint)
         expected = (expected == image)
-        with expected_warnings(["indices argument is deprecated"]):
-            result = peak.peak_local_max(image, labels=labels,
-                                         footprint=footprint,
-                                         min_distance=1,
-                                         threshold_rel=0,
-                                         indices=False,
-                                         exclude_border=False)
+        peak_idx = peak.peak_local_max(image, labels=labels,
+                                       footprint=footprint,
+                                       min_distance=1,
+                                       threshold_rel=0,
+                                       exclude_border=False)
+        result = np.zeros_like(image, dtype=bool)
+        result[tuple(peak_idx.T)] = True
         assert np.all(result == expected)
 
     def test_disk(self):
@@ -360,30 +335,34 @@ class TestPeakLocalMax():
         '''
         image = np.random.uniform(size=(10, 20))
         footprint = np.array([[1]])
-        with expected_warnings(["indices argument is deprecated"]):
-            result = peak.peak_local_max(image, labels=np.ones((10, 20), int),
-                                         footprint=footprint,
-                                         min_distance=1, threshold_rel=0,
-                                         threshold_abs=-1, indices=False,
-                                         exclude_border=False)
+        peak_idx = peak.peak_local_max(image, labels=np.ones((10, 20), int),
+                                       footprint=footprint,
+                                       min_distance=1, threshold_rel=0,
+                                       threshold_abs=-1,
+                                       exclude_border=False)
+        result = np.zeros_like(image, dtype=bool)
+        result[tuple(peak_idx.T)] = True
         assert np.all(result)
-        with expected_warnings(["indices argument is deprecated"]):
-            result = peak.peak_local_max(image, footprint=footprint,
-                                         threshold_abs=-1,
-                                         indices=False,
-                                         exclude_border=False)
+        peak_idx = peak.peak_local_max(image, footprint=footprint,
+                                       threshold_abs=-1,
+                                       exclude_border=False)
+        result = np.zeros_like(image, dtype=bool)
+        result[tuple(peak_idx.T)] = True
         assert np.all(result)
 
     def test_3D(self):
         image = np.zeros((30, 30, 30))
         image[15, 15, 15] = 1
         image[5, 5, 5] = 1
-        assert_equal(peak.peak_local_max(image, min_distance=10, threshold_rel=0),
-                     [[15, 15, 15]])
-        assert_equal(peak.peak_local_max(image, min_distance=6, threshold_rel=0),
-                     [[15, 15, 15]])
-        assert sorted(peak.peak_local_max(image, min_distance=10, threshold_rel=0,
-                                          exclude_border=False).tolist()) == \
+        assert_array_equal(
+            peak.peak_local_max(image, min_distance=10, threshold_rel=0),
+            [[15, 15, 15]])
+        assert_array_equal(
+            peak.peak_local_max(image, min_distance=6, threshold_rel=0),
+            [[15, 15, 15]])
+        assert sorted(
+            peak.peak_local_max(image, min_distance=10, threshold_rel=0,
+                                exclude_border=False).tolist()) == \
             [[5, 5, 5], [15, 15, 15]]
         assert sorted(peak.peak_local_max(image, min_distance=5,
                                           threshold_rel=0).tolist()) == \
@@ -393,13 +372,16 @@ class TestPeakLocalMax():
         image = np.zeros((30, 30, 30, 30))
         image[15, 15, 15, 15] = 1
         image[5, 5, 5, 5] = 1
-        assert_equal(peak.peak_local_max(image, min_distance=10, threshold_rel=0),
-                     [[15, 15, 15, 15]])
-        assert_equal(peak.peak_local_max(image, min_distance=6, threshold_rel=0),
-                     [[15, 15, 15, 15]])
-        assert sorted(peak.peak_local_max(image, min_distance=10, threshold_rel=0,
-                                          exclude_border=False).tolist()) == \
-            [[5, 5, 5, 5], [15, 15, 15, 15]]
+        assert_array_equal(
+            peak.peak_local_max(image, min_distance=10, threshold_rel=0),
+            [[15, 15, 15, 15]])
+        assert_array_equal(
+            peak.peak_local_max(image, min_distance=6, threshold_rel=0),
+            [[15, 15, 15, 15]])
+        assert sorted(
+            peak.peak_local_max(image, min_distance=10, threshold_rel=0,
+                                exclude_border=False).tolist()
+        ) == [[5, 5, 5, 5], [15, 15, 15, 15]]
         assert sorted(peak.peak_local_max(image, min_distance=5,
                                           threshold_rel=0).tolist()) == \
             [[5, 5, 5, 5], [15, 15, 15, 15]]
@@ -411,13 +393,26 @@ class TestPeakLocalMax():
         assert len(peak.peak_local_max(image)) == 0
 
         image[2, 2] = 2
-        assert_equal(peak.peak_local_max(image), [[2, 2]])
+        assert_array_equal(peak.peak_local_max(image), [[2, 2]])
 
         image[2, 2] = 0
         with expected_warnings(["When min_distance < 1"]):
             assert len(peak.peak_local_max(image,
                                            min_distance=0)) == image.size - 1
 
+    def test_peak_at_border(self):
+        image = np.full((10, 10), -2)
+        image[2, 4] = -1
+        image[3, 0] = -1
+
+        peaks = peak.peak_local_max(image, min_distance=3)
+        assert peaks.size == 0
+
+        peaks = peak.peak_local_max(image, min_distance=3, exclude_border=0)
+        assert len(peaks) == 2
+        assert [2, 4] in peaks
+        assert [3, 0] in peaks
+
 
 @pytest.mark.parametrize(
     ["indices"],
@@ -487,7 +482,23 @@ def test_exclude_border_errors():
         assert peak.peak_local_max(image, exclude_border=-1)
 
 
-class TestProminentPeaks(unittest.TestCase):
+def test_input_values_with_labels():
+    # Issue #5235: input values may be modified when labels are used
+
+    img = np.random.rand(128, 128)
+    labels = np.zeros((128, 128), int)
+
+    labels[10:20, 10:20] = 1
+    labels[12:16, 12:16] = 0
+
+    img_before = img.copy()
+
+    _ = peak.peak_local_max(img, labels=labels)
+
+    assert_array_equal(img, img_before)
+
+
+class TestProminentPeaks():
     def test_isolated_peaks(self):
         image = np.zeros((15, 15))
         x0, y0, i0 = (12, 8, 1)
@@ -498,10 +509,10 @@ class TestProminentPeaks(unittest.TestCase):
         image[y2, x2] = i2
         out = peak._prominent_peaks(image)
         assert len(out[0]) == 3
-        for i, x, y in zip (out[0], out[1], out[2]):
-            self.assertTrue(i in (i0, i1, i2))
-            self.assertTrue(x in (x0, x1, x2))
-            self.assertTrue(y in (y0, y1, y2))
+        for i, x, y in zip(out[0], out[1], out[2]):
+            assert i in (i0, i1, i2)
+            assert x in (x0, x1, x2)
+            assert y in (y0, y1, y2)
 
     def test_threshold(self):
         image = np.zeros((15, 15))
@@ -513,20 +524,20 @@ class TestProminentPeaks(unittest.TestCase):
         image[y2, x2] = i2
         out = peak._prominent_peaks(image, threshold=None)
         assert len(out[0]) == 3
-        for i, x, y in zip (out[0], out[1], out[2]):
-            self.assertTrue(i in (i0, i1, i2))
-            self.assertTrue(x in (x0, x1, x2))
+        for i, x, y in zip(out[0], out[1], out[2]):
+            assert i in (i0, i1, i2)
+            assert x in (x0, x1, x2)
         out = peak._prominent_peaks(image, threshold=9)
         assert len(out[0]) == 2
-        for i, x, y in zip (out[0], out[1], out[2]):
-            self.assertTrue(i in (i0, i2))
-            self.assertTrue(x in (x0, x2))
-            self.assertTrue(y in (y0, y2))
+        for i, x, y in zip(out[0], out[1], out[2]):
+            assert i in (i0, i2)
+            assert x in (x0, x2)
+            assert y in (y0, y2)
 
     def test_peaks_in_contact(self):
         image = np.zeros((15, 15))
         x0, y0, i0 = (8, 8, 1)
-        x1, y1, i1 = (7, 7, 1) # prominent peak
+        x1, y1, i1 = (7, 7, 1)  # prominent peak
         x2, y2, i2 = (6, 6, 1)
         image[y0, x0] = i0
         image[y1, x1] = i1
@@ -543,11 +554,10 @@ class TestProminentPeaks(unittest.TestCase):
         image[5, 5] = 1
         labels[5, 5] = 3
         labelsin = labels.copy()
-        with expected_warnings(["indices argument is deprecated"]):
-            peak.peak_local_max(image, labels=labels,
-                                footprint=np.ones((3, 3), bool),
-                                min_distance=1, threshold_rel=0,
-                                indices=False, exclude_border=False)
+        peak.peak_local_max(image, labels=labels,
+                            footprint=np.ones((3, 3), bool),
+                            min_distance=1, threshold_rel=0,
+                            exclude_border=False)
         assert np.all(labels == labelsin)
 
     def test_many_objects(self):
