@@ -23,7 +23,6 @@ References
 """
 
 from ..._shared.utils import check_nD
-
 from . import percentile_cy
 from .generic import _preprocess_input
 
@@ -33,32 +32,33 @@ __all__ = ['autolevel_percentile', 'gradient_percentile',
            'threshold_percentile']
 
 
-def _apply(func, image, selem, out, mask, shift_x, shift_y, p0, p1,
+def _apply(func, image, footprint, out, mask, shift_x, shift_y, p0, p1,
            out_dtype=None):
     check_nD(image, 2)
-    image, selem, out, mask, n_bins = _preprocess_input(image, selem, out, mask,
-                                                    out_dtype)
+    image, footprint, out, mask, n_bins = _preprocess_input(
+        image, footprint, out, mask, out_dtype
+    )
 
-    func(image, selem, shift_x=shift_x, shift_y=shift_y, mask=mask,
+    func(image, footprint, shift_x=shift_x, shift_y=shift_y, mask=mask,
          out=out, n_bins=n_bins, p0=p0, p1=p1)
 
     return out.reshape(out.shape[:2])
 
 
-def autolevel_percentile(image, selem, out=None, mask=None, shift_x=False,
+def autolevel_percentile(image, footprint, out=None, mask=None, shift_x=False,
                          shift_y=False, p0=0, p1=1):
-    """Return greyscale local autolevel of an image.
+    """Return grayscale local autolevel of an image.
 
-    This filter locally stretches the histogram of greyvalues to cover the
+    This filter locally stretches the histogram of grayvalues to cover the
     entire range of values from "white" to "black".
 
-    Only greyvalues between percentiles [p0, p1] are considered in the filter.
+    Only grayvalues between percentiles [p0, p1] are considered in the filter.
 
     Parameters
     ----------
     image : 2-D array (uint8, uint16)
         Input image.
-    selem : 2-D array
+    footprint : 2-D array
         The neighborhood expressed as a 2-D array of 1's and 0's.
     out : 2-D array (same dtype as input)
         If None, a new array is allocated.
@@ -66,9 +66,8 @@ def autolevel_percentile(image, selem, out=None, mask=None, shift_x=False,
         Mask array that defines (>0) area of the image included in the local
         neighborhood. If None, the complete image is used (default).
     shift_x, shift_y : int
-        Offset added to the structuring element center point. Shift is bounded
-        to the structuring element sizes (center must be inside the given
-        structuring element).
+        Offset added to the footprint center point. Shift is bounded to the
+        footprint sizes (center must be inside the given footprint).
     p0, p1 : float in [0, ..., 1]
         Define the [p0, p1] percentile interval to be considered for computing
         the value.
@@ -81,21 +80,21 @@ def autolevel_percentile(image, selem, out=None, mask=None, shift_x=False,
     """
 
     return _apply(percentile_cy._autolevel,
-                  image, selem, out=out, mask=mask, shift_x=shift_x,
+                  image, footprint, out=out, mask=mask, shift_x=shift_x,
                   shift_y=shift_y, p0=p0, p1=p1)
 
 
-def gradient_percentile(image, selem, out=None, mask=None, shift_x=False,
+def gradient_percentile(image, footprint, out=None, mask=None, shift_x=False,
                         shift_y=False, p0=0, p1=1):
     """Return local gradient of an image (i.e. local maximum - local minimum).
 
-    Only greyvalues between percentiles [p0, p1] are considered in the filter.
+    Only grayvalues between percentiles [p0, p1] are considered in the filter.
 
     Parameters
     ----------
     image : 2-D array (uint8, uint16)
         Input image.
-    selem : 2-D array
+    footprint : 2-D array
         The neighborhood expressed as a 2-D array of 1's and 0's.
     out : 2-D array (same dtype as input)
         If None, a new array is allocated.
@@ -103,9 +102,8 @@ def gradient_percentile(image, selem, out=None, mask=None, shift_x=False,
         Mask array that defines (>0) area of the image included in the local
         neighborhood. If None, the complete image is used (default).
     shift_x, shift_y : int
-        Offset added to the structuring element center point. Shift is bounded
-        to the structuring element sizes (center must be inside the given
-        structuring element).
+        Offset added to the footprint center point. Shift is bounded to the
+        footprint sizes (center must be inside the given footprint).
     p0, p1 : float in [0, ..., 1]
         Define the [p0, p1] percentile interval to be considered for computing
         the value.
@@ -118,21 +116,21 @@ def gradient_percentile(image, selem, out=None, mask=None, shift_x=False,
     """
 
     return _apply(percentile_cy._gradient,
-                  image, selem, out=out, mask=mask, shift_x=shift_x,
+                  image, footprint, out=out, mask=mask, shift_x=shift_x,
                   shift_y=shift_y, p0=p0, p1=p1)
 
 
-def mean_percentile(image, selem, out=None, mask=None, shift_x=False,
+def mean_percentile(image, footprint, out=None, mask=None, shift_x=False,
                     shift_y=False, p0=0, p1=1):
     """Return local mean of an image.
 
-    Only greyvalues between percentiles [p0, p1] are considered in the filter.
+    Only grayvalues between percentiles [p0, p1] are considered in the filter.
 
     Parameters
     ----------
     image : 2-D array (uint8, uint16)
         Input image.
-    selem : 2-D array
+    footprint : 2-D array
         The neighborhood expressed as a 2-D array of 1's and 0's.
     out : 2-D array (same dtype as input)
         If None, a new array is allocated.
@@ -140,9 +138,8 @@ def mean_percentile(image, selem, out=None, mask=None, shift_x=False,
         Mask array that defines (>0) area of the image included in the local
         neighborhood. If None, the complete image is used (default).
     shift_x, shift_y : int
-        Offset added to the structuring element center point. Shift is bounded
-        to the structuring element sizes (center must be inside the given
-        structuring element).
+        Offset added to the footprint center point. Shift is bounded to the
+        footprint sizes (center must be inside the given footprint).
     p0, p1 : float in [0, ..., 1]
         Define the [p0, p1] percentile interval to be considered for computing
         the value.
@@ -155,21 +152,21 @@ def mean_percentile(image, selem, out=None, mask=None, shift_x=False,
     """
 
     return _apply(percentile_cy._mean,
-                  image, selem, out=out, mask=mask, shift_x=shift_x,
+                  image, footprint, out=out, mask=mask, shift_x=shift_x,
                   shift_y=shift_y, p0=p0, p1=p1)
 
 
-def subtract_mean_percentile(image, selem, out=None, mask=None,
+def subtract_mean_percentile(image, footprint, out=None, mask=None,
                              shift_x=False, shift_y=False, p0=0, p1=1):
     """Return image subtracted from its local mean.
 
-    Only greyvalues between percentiles [p0, p1] are considered in the filter.
+    Only grayvalues between percentiles [p0, p1] are considered in the filter.
 
     Parameters
     ----------
     image : 2-D array (uint8, uint16)
         Input image.
-    selem : 2-D array
+    footprint : 2-D array
         The neighborhood expressed as a 2-D array of 1's and 0's.
     out : 2-D array (same dtype as input)
         If None, a new array is allocated.
@@ -177,9 +174,8 @@ def subtract_mean_percentile(image, selem, out=None, mask=None,
         Mask array that defines (>0) area of the image included in the local
         neighborhood. If None, the complete image is used (default).
     shift_x, shift_y : int
-        Offset added to the structuring element center point. Shift is bounded
-        to the structuring element sizes (center must be inside the given
-        structuring element).
+        Offset added to the footprint center point. Shift is bounded to the
+        footprint sizes (center must be inside the given footprint).
     p0, p1 : float in [0, ..., 1]
         Define the [p0, p1] percentile interval to be considered for computing
         the value.
@@ -192,25 +188,25 @@ def subtract_mean_percentile(image, selem, out=None, mask=None,
     """
 
     return _apply(percentile_cy._subtract_mean,
-                  image, selem, out=out, mask=mask, shift_x=shift_x,
+                  image, footprint, out=out, mask=mask, shift_x=shift_x,
                   shift_y=shift_y, p0=p0, p1=p1)
 
 
-def enhance_contrast_percentile(image, selem, out=None, mask=None,
+def enhance_contrast_percentile(image, footprint, out=None, mask=None,
                                 shift_x=False, shift_y=False, p0=0, p1=1):
     """Enhance contrast of an image.
 
-    This replaces each pixel by the local maximum if the pixel greyvalue is
+    This replaces each pixel by the local maximum if the pixel grayvalue is
     closer to the local maximum than the local minimum. Otherwise it is
     replaced by the local minimum.
 
-    Only greyvalues between percentiles [p0, p1] are considered in the filter.
+    Only grayvalues between percentiles [p0, p1] are considered in the filter.
 
     Parameters
     ----------
     image : 2-D array (uint8, uint16)
         Input image.
-    selem : 2-D array
+    footprint : 2-D array
         The neighborhood expressed as a 2-D array of 1's and 0's.
     out : 2-D array (same dtype as input)
         If None, a new array is allocated.
@@ -218,9 +214,8 @@ def enhance_contrast_percentile(image, selem, out=None, mask=None,
         Mask array that defines (>0) area of the image included in the local
         neighborhood. If None, the complete image is used (default).
     shift_x, shift_y : int
-        Offset added to the structuring element center point. Shift is bounded
-        to the structuring element sizes (center must be inside the given
-        structuring element).
+        Offset added to the footprint center point. Shift is bounded to the
+        footprint sizes (center must be inside the given footprint).
     p0, p1 : float in [0, ..., 1]
         Define the [p0, p1] percentile interval to be considered for computing
         the value.
@@ -233,24 +228,24 @@ def enhance_contrast_percentile(image, selem, out=None, mask=None,
     """
 
     return _apply(percentile_cy._enhance_contrast,
-                  image, selem, out=out, mask=mask, shift_x=shift_x,
+                  image, footprint, out=out, mask=mask, shift_x=shift_x,
                   shift_y=shift_y, p0=p0, p1=p1)
 
 
-def percentile(image, selem, out=None, mask=None, shift_x=False, shift_y=False,
-               p0=0):
+def percentile(image, footprint, out=None, mask=None, shift_x=False,
+               shift_y=False, p0=0):
     """Return local percentile of an image.
 
-    Returns the value of the p0 lower percentile of the local greyvalue
+    Returns the value of the p0 lower percentile of the local grayvalue
     distribution.
 
-    Only greyvalues between percentiles [p0, p1] are considered in the filter.
+    Only grayvalues between percentiles [p0, p1] are considered in the filter.
 
     Parameters
     ----------
     image : 2-D array (uint8, uint16)
         Input image.
-    selem : 2-D array
+    footprint : 2-D array
         The neighborhood expressed as a 2-D array of 1's and 0's.
     out : 2-D array (same dtype as input)
         If None, a new array is allocated.
@@ -258,9 +253,8 @@ def percentile(image, selem, out=None, mask=None, shift_x=False, shift_y=False,
         Mask array that defines (>0) area of the image included in the local
         neighborhood. If None, the complete image is used (default).
     shift_x, shift_y : int
-        Offset added to the structuring element center point. Shift is bounded
-        to the structuring element sizes (center must be inside the given
-        structuring element).
+        Offset added to the footprint center point. Shift is bounded to the
+        footprint sizes (center must be inside the given footprint).
     p0 : float in [0, ..., 1]
         Set the percentile value.
 
@@ -272,24 +266,24 @@ def percentile(image, selem, out=None, mask=None, shift_x=False, shift_y=False,
     """
 
     return _apply(percentile_cy._percentile,
-                  image, selem, out=out, mask=mask, shift_x=shift_x,
+                  image, footprint, out=out, mask=mask, shift_x=shift_x,
                   shift_y=shift_y, p0=p0, p1=0.)
 
 
-def pop_percentile(image, selem, out=None, mask=None, shift_x=False,
+def pop_percentile(image, footprint, out=None, mask=None, shift_x=False,
                    shift_y=False, p0=0, p1=1):
     """Return the local number (population) of pixels.
 
     The number of pixels is defined as the number of pixels which are included
-    in the structuring element and the mask.
+    in the footprint and the mask.
 
-    Only greyvalues between percentiles [p0, p1] are considered in the filter.
+    Only grayvalues between percentiles [p0, p1] are considered in the filter.
 
     Parameters
     ----------
     image : 2-D array (uint8, uint16)
         Input image.
-    selem : 2-D array
+    footprint : 2-D array
         The neighborhood expressed as a 2-D array of 1's and 0's.
     out : 2-D array (same dtype as input)
         If None, a new array is allocated.
@@ -297,9 +291,8 @@ def pop_percentile(image, selem, out=None, mask=None, shift_x=False,
         Mask array that defines (>0) area of the image included in the local
         neighborhood. If None, the complete image is used (default).
     shift_x, shift_y : int
-        Offset added to the structuring element center point. Shift is bounded
-        to the structuring element sizes (center must be inside the given
-        structuring element).
+        Offset added to the footprint center point. Shift is bounded to the
+        footprint sizes (center must be inside the given footprint).
     p0, p1 : float in [0, ..., 1]
         Define the [p0, p1] percentile interval to be considered for computing
         the value.
@@ -312,15 +305,15 @@ def pop_percentile(image, selem, out=None, mask=None, shift_x=False,
     """
 
     return _apply(percentile_cy._pop,
-                  image, selem, out=out, mask=mask, shift_x=shift_x,
+                  image, footprint, out=out, mask=mask, shift_x=shift_x,
                   shift_y=shift_y, p0=p0, p1=p1)
 
 
-def sum_percentile(image, selem, out=None, mask=None, shift_x=False,
+def sum_percentile(image, footprint, out=None, mask=None, shift_x=False,
                    shift_y=False, p0=0, p1=1):
     """Return the local sum of pixels.
 
-    Only greyvalues between percentiles [p0, p1] are considered in the filter.
+    Only grayvalues between percentiles [p0, p1] are considered in the filter.
 
     Note that the sum may overflow depending on the data type of the input
     array.
@@ -329,7 +322,7 @@ def sum_percentile(image, selem, out=None, mask=None, shift_x=False,
     ----------
     image : 2-D array (uint8, uint16)
         Input image.
-    selem : 2-D array
+    footprint : 2-D array
         The neighborhood expressed as a 2-D array of 1's and 0's.
     out : 2-D array (same dtype as input)
         If None, a new array is allocated.
@@ -337,9 +330,8 @@ def sum_percentile(image, selem, out=None, mask=None, shift_x=False,
         Mask array that defines (>0) area of the image included in the local
         neighborhood. If None, the complete image is used (default).
     shift_x, shift_y : int
-        Offset added to the structuring element center point. Shift is bounded
-        to the structuring element sizes (center must be inside the given
-        structuring element).
+        Offset added to the footprint center point. Shift is bounded to the
+        footprint sizes (center must be inside the given footprint).
     p0, p1 : float in [0, ..., 1]
         Define the [p0, p1] percentile interval to be considered for computing
         the value.
@@ -352,24 +344,24 @@ def sum_percentile(image, selem, out=None, mask=None, shift_x=False,
     """
 
     return _apply(percentile_cy._sum,
-                  image, selem, out=out, mask=mask, shift_x=shift_x,
+                  image, footprint, out=out, mask=mask, shift_x=shift_x,
                   shift_y=shift_y, p0=p0, p1=p1)
 
 
-def threshold_percentile(image, selem, out=None, mask=None, shift_x=False,
+def threshold_percentile(image, footprint, out=None, mask=None, shift_x=False,
                          shift_y=False, p0=0):
     """Local threshold of an image.
 
-    The resulting binary mask is True if the greyvalue of the center pixel is
+    The resulting binary mask is True if the grayvalue of the center pixel is
     greater than the local mean.
 
-    Only greyvalues between percentiles [p0, p1] are considered in the filter.
+    Only grayvalues between percentiles [p0, p1] are considered in the filter.
 
     Parameters
     ----------
     image : 2-D array (uint8, uint16)
         Input image.
-    selem : 2-D array
+    footprint : 2-D array
         The neighborhood expressed as a 2-D array of 1's and 0's.
     out : 2-D array (same dtype as input)
         If None, a new array is allocated.
@@ -377,9 +369,8 @@ def threshold_percentile(image, selem, out=None, mask=None, shift_x=False,
         Mask array that defines (>0) area of the image included in the local
         neighborhood. If None, the complete image is used (default).
     shift_x, shift_y : int
-        Offset added to the structuring element center point. Shift is bounded
-        to the structuring element sizes (center must be inside the given
-        structuring element).
+        Offset added to the footprint center point. Shift is bounded to the
+        footprint sizes (center must be inside the given footprint).
     p0 : float in [0, ..., 1]
         Set the percentile value.
 
@@ -391,5 +382,5 @@ def threshold_percentile(image, selem, out=None, mask=None, shift_x=False,
     """
 
     return _apply(percentile_cy._threshold,
-                  image, selem, out=out, mask=mask, shift_x=shift_x,
+                  image, footprint, out=out, mask=mask, shift_x=shift_x,
                   shift_y=shift_y, p0=p0, p1=0)
