@@ -1,3 +1,5 @@
+import math
+
 import numpy as np
 import pytest
 from numpy.testing import (assert_allclose, assert_almost_equal,
@@ -29,7 +31,7 @@ from skimage.filters.thresholding import (_cross_entropy, _mean_std,
 
 
 class TestSimpleImage():
-    def setup(self):
+    def setup_method(self):
         self.image = np.array([[0, 0, 1, 3, 5],
                                [0, 1, 4, 3, 4],
                                [1, 2, 5, 4, 1],
@@ -386,19 +388,26 @@ def test_li_negative_inital_guess():
         threshold_li(coins, initial_guess=-5)
 
 
-def test_li_pathological_arrays():
-    # See https://github.com/scikit-image/scikit-image/issues/4140
-    a = np.array([0, 0, 1, 0, 0, 1, 0, 1])
-    b = np.array([0, 0, 0.1, 0, 0, 0.1, 0, 0.1])
-    c = np.array([0, 0, 0.1, 0, 0, 0.1, 0.01, 0.1])
-    d = np.array([0, 0, 1, 0, 0, 1, 0.5, 1])
-    e = np.array([1, 1])
-    f = np.array([1, 2])
-    arrays = [a, b, c, d, e, f]
-    with np.errstate(divide='ignore'):
-        # ignoring "divide by zero encountered in log" error from np.log(0)
-        thresholds = [threshold_li(arr) for arr in arrays]
-    assert np.all(np.isfinite(thresholds))
+@pytest.mark.parametrize(
+    "image",
+    [
+        # See https://github.com/scikit-image/scikit-image/issues/4140
+        [0, 0, 1, 0, 0, 1, 0, 1],
+        [0, 0, 0.1, 0, 0, 0.1, 0, 0.1],
+        [0, 0, 0.1, 0, 0, 0.1, 0.01, 0.1],
+        [0, 0, 1, 0, 0, 1, 0.5, 1],
+        [1, 1],
+        [1, 2],
+        # See https://github.com/scikit-image/scikit-image/issues/6744
+        [0, 254, 255],
+        [0, 1, 255],
+        [0.1, 0.8, 0.9]
+    ]
+)
+def test_li_pathological(image):
+    image = np.array(image)
+    threshold = threshold_li(image)
+    assert np.isfinite(threshold)
 
 
 def test_yen_camera_image():
@@ -531,13 +540,6 @@ def test_threshold_minimum_histogram():
     assert_equal(threshold, 85)
 
 
-def test_threshold_minimum_deprecated_max_iter_kwarg():
-    camera = util.img_as_ubyte(data.camera())
-    hist = histogram(camera.ravel(), 256, source_range='image')
-    with expected_warnings(["`max_iter` is a deprecated argument"]):
-        threshold_minimum(hist=hist, max_iter=5000)
-
-
 def test_threshold_minimum_counts():
     camera = util.img_as_ubyte(data.camera())
     counts, bin_centers = histogram(camera.ravel(), 256, source_range='image')
@@ -566,6 +568,11 @@ def test_mean():
     img[:, 4:] = 2
     assert(threshold_mean(img) == 1.)
 
+@pytest.mark.parametrize("dtype", [np.uint8, np.int16, np.float16, np.float32])
+def test_triangle_uniform_images(dtype):
+    assert threshold_triangle(np.zeros((10, 10), dtype=dtype)) == 0
+    assert threshold_triangle(np.ones((10, 10), dtype=dtype)) == 1
+    assert threshold_triangle(np.full((10, 10), 2, dtype=dtype)) == 2
 
 def test_triangle_uint_images():
     assert(threshold_triangle(np.invert(data.text())) == 151)
@@ -611,9 +618,9 @@ def test_triangle_flip():
     "window_size, mean_kernel",
     [(11, np.full((11,) * 2,  1 / 11 ** 2)),
      ((11, 11), np.full((11, 11), 1 / 11 ** 2)),
-     ((9, 13), np.full((9, 13), 1 / np.prod((9, 13)))),
-     ((13, 9), np.full((13, 9), 1 / np.prod((13, 9)))),
-     ((1, 9), np.full((1, 9), 1 / np.prod((1, 9))))
+     ((9, 13), np.full((9, 13), 1 / math.prod((9, 13)))),
+     ((13, 9), np.full((13, 9), 1 / math.prod((13, 9)))),
+     ((1, 9), np.full((1, 9), 1 / math.prod((1, 9))))
      ]
 )
 def test_mean_std_2d(window_size, mean_kernel):
@@ -631,7 +638,7 @@ def test_mean_std_2d(window_size, mean_kernel):
         (5, np.full((5,) * 3, 1 / 5) ** 3),
         ((5, 5, 5), np.full((5, 5, 5), 1 / 5 ** 3)),
         ((1, 5, 5), np.full((1, 5, 5), 1 / 5 ** 2)),
-        ((3, 5, 7), np.full((3, 5, 7), 1 / np.prod((3, 5, 7))))]
+        ((3, 5, 7), np.full((3, 5, 7), 1 / math.prod((3, 5, 7))))]
 )
 def test_mean_std_3d(window_size, mean_kernel):
     image = np.random.rand(40, 40, 40)
