@@ -52,7 +52,7 @@ def _update_doc(doc):
         name_column = [name]
         name_column.extend(['' for _ in range(len(description_lines) - 1)])
         for name, description in zip(name_column, description_lines):
-            doc += "%s %s\n" % (name.ljust(name_length), description)
+            doc += f"{name.ljust(name_length)} {description}\n"
     doc = doc.strip()
 
     return doc
