@@ -134,12 +134,12 @@ def imsave(fname, arr, plugin=None, check_contrast=True, **plugin_args):
         if fname.lower().endswith(('.tiff', '.tif')):
             plugin = 'tifffile'
     if arr.dtype == bool:
-        warn('%s is a boolean image: setting True to 255 and False to 0. '
+        warn(f'{fname} is a boolean image: setting True to 255 and False to 0. '
              'To silence this warning, please convert the image using '
-             'img_as_ubyte.' % fname, stacklevel=2)
+             'img_as_ubyte.', stacklevel=2)
         arr = arr.astype('uint8') * 255
     if check_contrast and is_low_contrast(arr):
-        warn('%s is a low contrast image' % fname)
+        warn(f'{fname} is a low contrast image')
     return call_plugin('imsave', fname, arr, plugin=plugin, **plugin_args)
 
 
