@@ -1,5 +1,4 @@
 import numpy as np
-from skimage._shared.utils import deprecate_kwarg
 
 from ._find_contours_cy import _get_contour_segments
 
@@ -8,7 +7,6 @@ from collections import deque
 _param_options = ('high', 'low')
 
 
-@deprecate_kwarg({'array': 'image'}, removed_version="0.20")
 def find_contours(image, level=None,
                   fully_connected='low', positive_orientation='low',
                   *,
@@ -146,7 +144,7 @@ def find_contours(image, level=None,
     if level is None:
         level = (np.nanmin(image) + np.nanmax(image)) / 2.0
 
-    segments = _get_contour_segments(image.astype(np.double), float(level),
+    segments = _get_contour_segments(image.astype(np.float64), float(level),
                                      fully_connected == 'high', mask=mask)
     contours = _assemble_contours(segments)
     if positive_orientation == 'high':
@@ -174,8 +172,7 @@ def _assemble_contours(segments):
         if tail is not None and head is not None:
             # We need to connect these two contours.
             if tail is head:
-                # We need to closed a contour.
-                # Add the end point
+                # We need to closed a contour: add the end point
                 head.append(to_point)
             else:  # tail is not head
                 # We need to join two distinct contours.
@@ -184,37 +181,38 @@ def _assemble_contours(segments):
                 if tail_num > head_num:
                     # tail was created second. Append tail to head.
                     head.extend(tail)
-                    # remove all traces of tail:
-                    ends.pop(tail[-1])
+                    # Remove tail from the detected contours
                     contours.pop(tail_num, None)
-                    # Update contour starts end ends
+                    # Update starts and ends
                     starts[head[0]] = (head, head_num)
                     ends[head[-1]] = (head, head_num)
                 else:  # tail_num <= head_num
                     # head was created second. Prepend head to tail.
                     tail.extendleft(reversed(head))
-                    # remove all traces of head:
-                    starts.pop(head[0])
+                    # Remove head from the detected contours
+                    starts.pop(head[0], None)  # head[0] can be == to_point!
                     contours.pop(head_num, None)
-                    # Update contour starts end ends
+                    # Update starts and ends
                     starts[tail[0]] = (tail, tail_num)
                     ends[tail[-1]] = (tail, tail_num)
         elif tail is None and head is None:
-            # we need to add a new contour
+            # We need to add a new contour
             new_contour = deque((from_point, to_point))
             contours[current_index] = new_contour
             starts[from_point] = (new_contour, current_index)
             ends[to_point] = (new_contour, current_index)
             current_index += 1
         elif head is None:  # tail is not None
-            # We've found a single contour to which the new segment should be
+            # tail first element is to_point: the new segment should be
             # prepended.
             tail.appendleft(from_point)
+            # Update starts
             starts[from_point] = (tail, tail_num)
         else:  # tail is None and head is not None:
-            # We've found a single contour to which the new segment should be
+            # head last element is from_point: the new segment should be
             # appended
             head.append(to_point)
+            # Update ends
             ends[to_point] = (head, head_num)
 
     return [np.array(contour) for _, contour in sorted(contours.items())]
