@@ -33,3 +33,17 @@ def test_grid_points_in_poly():
     expected = np.tril(np.ones((5, 5), dtype=bool))
 
     assert_array_equal(grid_points_in_poly((5, 5), v), expected)
+
+
+def test_grid_points_in_poly_binarize():
+    v = np.array([[0, 0],
+                  [5, 0],
+                  [5, 5]])
+
+    expected = np.array([[2, 0, 0, 0, 0],
+                        [3, 3, 0, 0, 0],
+                        [3, 1, 3, 0, 0],
+                        [3, 1, 1, 3, 0],
+                        [3, 1, 1, 1, 3]])
+
+    assert_array_equal(grid_points_in_poly((5, 5), v, binarize=False), expected)
