@@ -1,10 +1,13 @@
 import numpy as np
+from scipy.stats import entropy
+
 from ..util.dtype import dtype_range
-from .._shared.utils import warn, check_shape_equality
+from .._shared.utils import _supported_float_type, check_shape_equality, warn
 
 __all__ = ['mean_squared_error',
            'normalized_root_mse',
            'peak_signal_noise_ratio',
+           'normalized_mutual_information',
            ]
 
 
@@ -12,7 +15,7 @@ def _as_floats(image0, image1):
     """
     Promote im1, im2 to nearest appropriate floating point precision.
     """
-    float_type = np.result_type(image0.dtype, image1.dtype, np.float32)
+    float_type = _supported_float_type((image0.dtype, image1.dtype))
     image0 = np.asarray(image0, dtype=float_type)
     image1 = np.asarray(image1, dtype=float_type)
     return image0, image1
@@ -141,13 +144,13 @@ def peak_signal_noise_ratio(image_true, image_test, *, data_range=None):
     if data_range is None:
         if image_true.dtype != image_test.dtype:
             warn("Inputs have mismatched dtype.  Setting data_range based on "
-                 "im_true.", stacklevel=2)
+                 "image_true.")
         dmin, dmax = dtype_range[image_true.dtype.type]
         true_min, true_max = np.min(image_true), np.max(image_true)
         if true_max > dmax or true_min < dmin:
             raise ValueError(
-                "im_true has intensity values outside the range expected for "
-                "its data type.  Please manually specify the data_range")
+                "image_true has intensity values outside the range expected "
+                "for its data type. Please manually specify the data_range.")
         if true_min >= 0:
             # most common case (255 for uint8, 1 for float)
             data_range = dmax
@@ -158,3 +161,101 @@ def peak_signal_noise_ratio(image_true, image_test, *, data_range=None):
 
     err = mean_squared_error(image_true, image_test)
     return 10 * np.log10((data_range ** 2) / err)
+
+
+def _pad_to(arr, shape):
+    """Pad an array with trailing zeros to a given target shape.
+
+    Parameters
+    ----------
+    arr : ndarray
+        The input array.
+    shape : tuple
+        The target shape.
+
+    Returns
+    -------
+    padded : ndarray
+        The padded array.
+
+    Examples
+    --------
+    >>> _pad_to(np.ones((1, 1), dtype=int), (1, 3))
+    array([[1, 0, 0]])
+    """
+    if not all(s >= i for s, i in zip(shape, arr.shape)):
+        raise ValueError(f'Target shape {shape} cannot be smaller than input'
+                         f'shape {arr.shape} along any axis.')
+    padding = [(0, s-i) for s, i in zip(shape, arr.shape)]
+    return np.pad(arr, pad_width=padding, mode='constant', constant_values=0)
+
+
+def normalized_mutual_information(image0, image1, *, bins=100):
+    r"""Compute the normalized mutual information (NMI).
+
+    The normalized mutual information of :math:`A` and :math:`B` is given by::
+
+    .. math::
+
+        Y(A, B) = \frac{H(A) + H(B)}{H(A, B)}
+
+    where :math:`H(X) := - \sum_{x \in X}{x \log x}` is the entropy.
+
+    It was proposed to be useful in registering images by Colin Studholme and
+    colleagues [1]_. It ranges from 1 (perfectly uncorrelated image values)
+    to 2 (perfectly correlated image values, whether positively or negatively).
+
+    Parameters
+    ----------
+    image0, image1 : ndarray
+        Images to be compared. The two input images must have the same number
+        of dimensions.
+    bins : int or sequence of int, optional
+        The number of bins along each axis of the joint histogram.
+
+    Returns
+    -------
+    nmi : float
+        The normalized mutual information between the two arrays, computed at
+        the granularity given by ``bins``. Higher NMI implies more similar
+        input images.
+
+    Raises
+    ------
+    ValueError
+        If the images don't have the same number of dimensions.
+
+    Notes
+    -----
+    If the two input images are not the same shape, the smaller image is padded
+    with zeros.
+
+    References
+    ----------
+    .. [1] C. Studholme, D.L.G. Hill, & D.J. Hawkes (1999). An overlap
+           invariant entropy measure of 3D medical image alignment.
+           Pattern Recognition 32(1):71-86
+           :DOI:`10.1016/S0031-3203(98)00091-0`
+    """
+    if image0.ndim != image1.ndim:
+        raise ValueError(f'NMI requires images of same number of dimensions. '
+                         f'Got {image0.ndim}D for `image0` and '
+                         f'{image1.ndim}D for `image1`.')
+    if image0.shape != image1.shape:
+        max_shape = np.maximum(image0.shape, image1.shape)
+        padded0 = _pad_to(image0, max_shape)
+        padded1 = _pad_to(image1, max_shape)
+    else:
+        padded0, padded1 = image0, image1
+
+    hist, bin_edges = np.histogramdd(
+            [np.reshape(padded0, -1), np.reshape(padded1, -1)],
+            bins=bins,
+            density=True,
+            )
+
+    H0 = entropy(np.sum(hist, axis=0))
+    H1 = entropy(np.sum(hist, axis=1))
+    H01 = entropy(np.reshape(hist, -1))
+
+    return (H0 + H1) / H01
