@@ -6,14 +6,12 @@ connected to a given seed point with a different value.
 
 import numpy as np
 
-from .._shared.utils import deprecate_kwarg
+from ..util import crop
 from ._flood_fill_cy import _flood_fill_equal, _flood_fill_tolerance
 from ._util import (_offsets_to_raveled_neighbors, _resolve_neighborhood,
                     _set_border_values,)
 
 
-@deprecate_kwarg(kwarg_mapping={'selem': 'footprint'}, removed_version="1.0",
-                 deprecated_version="0.19")
 def flood_fill(image, seed_point, new_value, *, footprint=None,
                connectivity=None, tolerance=None, in_place=False):
     """Perform flood filling on an image.
@@ -111,8 +109,6 @@ def flood_fill(image, seed_point, new_value, *, footprint=None,
     return image
 
 
-@deprecate_kwarg(kwarg_mapping={'selem': 'footprint'}, removed_version="1.0",
-                 deprecated_version="0.19")
 def flood(image, seed_point, *, footprint=None, connectivity=None,
           tolerance=None):
     """Mask corresponding to a flood fill.
@@ -134,7 +130,7 @@ def flood(image, seed_point, *, footprint=None, connectivity=None,
         are considered as part of the neighborhood (fully connected).
     connectivity : int, optional
         A number used to determine the neighborhood of each evaluated pixel.
-        Adjacent pixels whose squared distance from the center is larger or
+        Adjacent pixels whose squared distance from the center is less than or
         equal to `connectivity` are considered neighbors. Ignored if
         `footprint` is not None.
     tolerance : float or int, optional
@@ -230,22 +226,31 @@ def flood(image, seed_point, *, footprint=None, connectivity=None,
     seed_value = image[seed_point]
     seed_point = tuple(np.asarray(seed_point) % image.shape)
 
-    footprint = _resolve_neighborhood(footprint, connectivity, image.ndim)
+    footprint = _resolve_neighborhood(
+        footprint, connectivity, image.ndim, enforce_adjacency=False)
+    center = tuple(s // 2 for s in footprint.shape)
+    # Compute padding width as the maximum offset to neighbors on each axis.
+    # Generates a 2-tuple of (pad_start, pad_end) for each axis.
+    pad_width = [(np.max(np.abs(idx - c)),) * 2
+                 for idx, c in zip(np.nonzero(footprint), center)]
 
     # Must annotate borders
-    working_image = np.pad(image, 1, mode='constant',
+    working_image = np.pad(image, pad_width, mode='constant',
                            constant_values=image.min())
-
     # Stride-aware neighbors - works for both C- and Fortran-contiguity
-    ravelled_seed_idx = np.ravel_multi_index([i + 1 for i in seed_point],
-                                             working_image.shape, order=order)
+    ravelled_seed_idx = np.ravel_multi_index(
+        [i + pad_start
+         for i, (pad_start, pad_end) in zip(seed_point, pad_width)],
+        working_image.shape,
+        order=order
+    )
     neighbor_offsets = _offsets_to_raveled_neighbors(
-        working_image.shape, footprint, center=((1,) * image.ndim),
+        working_image.shape, footprint, center=center,
         order=order)
 
     # Use a set of flags; see _flood_fill_cy.pyx for meanings
     flags = np.zeros(working_image.shape, dtype=np.uint8, order=order)
-    _set_border_values(flags, value=2)
+    _set_border_values(flags, value=2, border_width=pad_width)
 
     try:
         if tolerance is not None:
@@ -282,4 +287,4 @@ def flood(image, seed_point, *, footprint=None, connectivity=None,
             raise
 
     # Output what the user requested; view does not create a new copy.
-    return flags[(slice(1, -1),) * image.ndim].view(bool)
+    return crop(flags, pad_width, copy=False).view(bool)
