@@ -1,16 +1,14 @@
 """
 Algorithms for computing the skeleton of a binary image
 """
-
-
 import numpy as np
-from ..util import img_as_ubyte, crop
 from scipy import ndimage as ndi
 
 from .._shared.utils import check_nD, deprecate_kwarg
+from ..util import crop, img_as_ubyte
+from ._skeletonize_3d_cy import _compute_thin_image
 from ._skeletonize_cy import (_fast_skeletonize, _skeletonize_loop,
                               _table_lookup_index)
-from ._skeletonize_3d_cy import _compute_thin_image
 
 
 def skeletonize(image, *, method=None):
@@ -22,7 +20,7 @@ def skeletonize(image, *, method=None):
     Parameters
     ----------
     image : ndarray, 2D or 3D
-        A binary image containing the objects to be skeletonized. Zeros
+        An image containing the objects to be skeletonized. Zeros
         represent background, nonzero values are foreground.
     method : {'zhang', 'lee'}, optional
         Which algorithm to use. Zhang's algorithm [Zha84]_ only works for
@@ -75,9 +73,11 @@ def skeletonize(image, *, method=None):
            [0, 0, 0, 0, 0, 0, 0, 0, 0]], dtype=uint8)
 
     """
-
+    if method not in {'zhang', 'lee', None}:
+        raise ValueError(f'skeletonize method should be either "lee" or "zhang", '
+                         f'got {method}.')
     if image.ndim == 2 and (method is None or method == 'zhang'):
-        skeleton = skeletonize_2d(image)
+        skeleton = skeletonize_2d(image.astype(bool, copy=False))
     elif image.ndim == 3 and method == 'zhang':
         raise ValueError('skeletonize method "zhang" only works for 2D '
                          'images.')
@@ -117,7 +117,7 @@ def skeletonize_2d(image):
     removing pixels on object borders. This continues until no
     more pixels can be removed.  The image is correlated with a
     mask that assigns each pixel a number in the range [0...255]
-    corresponding to each possible pattern of its 8 neighbouring
+    corresponding to each possible pattern of its 8 neighboring
     pixels. A look up table is then used to assign the pixels a
     value of 0, 1, 2 or 3, which are selectively removed during
     the iterations.
@@ -160,16 +160,8 @@ def skeletonize_2d(image):
 
     """
 
-    # convert to unsigned int (this should work for boolean values)
-    image = image.astype(np.uint8)
-
-    # check some properties of the input image:
-    #  - 2D
-    #  - binary image with only 0's and 1's
     if image.ndim != 2:
-        raise ValueError('Skeletonize requires a 2D array')
-    if not np.all(np.in1d(image.flat, (0, 1))):
-        raise ValueError('Image contains values other than 0 and 1')
+        raise ValueError("Zhang's skeletonize method requires a 2D array")
 
     return _fast_skeletonize(image)
 
@@ -254,8 +246,6 @@ G123P_LUT = np.array([0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0,
                       0, 0, 0, 0, 0, 0, 0, 0, 0], dtype=bool)
 
 
-@deprecate_kwarg({'max_iter': 'max_num_iter'}, removed_version="1.0",
-                 deprecated_version="0.19")
 def thin(image, max_num_iter=None):
     """
     Perform morphological thinning of a binary image.
@@ -360,7 +350,9 @@ def thin(image, max_num_iter=None):
 _eight_connect = ndi.generate_binary_structure(2, 2)
 
 
-def medial_axis(image, mask=None, return_distance=False, *, random_state=None):
+@deprecate_kwarg({'random_state': 'rng'}, deprecated_version='0.21',
+                 removed_version='0.23')
+def medial_axis(image, mask=None, return_distance=False, *, rng=None):
     """Compute the medial axis transform of a binary image.
 
     Parameters
@@ -372,13 +364,13 @@ def medial_axis(image, mask=None, return_distance=False, *, random_state=None):
         value in `mask` are used for computing the medial axis.
     return_distance : bool, optional
         If true, the distance transform is returned as well as the skeleton.
-    random_state : {None, int, `numpy.random.Generator`}, optional
-        If `random_state` is None the `numpy.random.Generator` singleton is
-        used.
-        If `random_state` is an int, a new ``Generator`` instance is used,
-        seeded with `random_state`.
-        If `random_state` is already a ``Generator`` instance then that
-        instance is used.
+    rng : {`numpy.random.Generator`, int}, optional
+        Pseudo-random number generator.
+        By default, a PCG64 generator is used (see :func:`numpy.random.default_rng`).
+        If `rng` is an int, it is used to seed the generator.
+
+        The PRNG determines the order in which pixels are processed for
+        tiebreaking.
 
         .. versionadded:: 0.19
 
@@ -453,7 +445,7 @@ def medial_axis(image, mask=None, return_distance=False, *, random_state=None):
     # (if the number of connected components is different with and
     # without the central pixel)
     # OR
-    # 3. Keep if # pixels in neighbourhood is 2 or less
+    # 3. Keep if # pixels in neighborhood is 2 or less
     # Note that table is independent of image
     center_is_foreground = (np.arange(512) & 2**4).astype(bool)
     table = (center_is_foreground  # condition 1.
@@ -479,7 +471,7 @@ def medial_axis(image, mask=None, return_distance=False, *, random_state=None):
     # with fewer neighbors are more "cornery" and should be processed last.
     # We use a cornerness_table lookup table where the score of a
     # configuration is the number of background (0-value) pixels in the
-    # 3x3 neighbourhood
+    # 3x3 neighborhood
     cornerness_table = np.array([9 - np.sum(_pattern_of(index))
                                  for index in range(512)])
     corner_score = _table_lookup(masked_image, cornerness_table)
@@ -497,7 +489,7 @@ def medial_axis(image, mask=None, return_distance=False, *, random_state=None):
     # predictable, random # so that masking doesn't affect arbitrary choices
     # of skeletons
     #
-    generator = np.random.default_rng(random_state)
+    generator = np.random.default_rng(rng)
     tiebreaker = generator.permutation(np.arange(masked_image.sum()))
     order = np.lexsort((tiebreaker,
                         corner_score[masked_image],
@@ -624,7 +616,7 @@ def skeletonize_3d(image):
     # make sure the image is 3D or 2D
     if image.ndim < 2 or image.ndim > 3:
         raise ValueError("skeletonize_3d can only handle 2D or 3D images; "
-                         "got image.ndim = %s instead." % image.ndim)
+                         f"got image.ndim = {image.ndim} instead.")
     image = np.ascontiguousarray(image)
     image = img_as_ubyte(image, force_copy=False)
 
