@@ -6,14 +6,32 @@ import functools
 import numpy as np
 from scipy import ndimage as ndi
 
-from .._shared.utils import deprecate_kwarg
 from ..util import crop
+from .footprints import _footprint_is_sequence, _shape_from_sequence
 from .misc import default_footprint
 
 __all__ = ['erosion', 'dilation', 'opening', 'closing', 'white_tophat',
            'black_tophat']
 
 
+def _iterate_gray_func(gray_func, image, footprints, out):
+    """Helper to call `binary_func` for each footprint in a sequence.
+
+    binary_func is a binary morphology function that accepts "structure",
+    "output" and "iterations" keyword arguments
+    (e.g. `scipy.ndimage.binary_erosion`).
+    """
+    fp, num_iter = footprints[0]
+    gray_func(image, footprint=fp, output=out)
+    for _ in range(1, num_iter):
+        gray_func(out.copy(), footprint=fp, output=out)
+    for fp, num_iter in footprints[1:]:
+        # Note: out.copy() because the computation cannot be in-place!
+        for _ in range(num_iter):
+            gray_func(out.copy(), footprint=fp, output=out)
+    return out
+
+
 def _shift_footprint(footprint, shift_x, shift_y):
     """Shift the binary image `footprint` in the left and/or up.
 
@@ -110,7 +128,13 @@ def pad_for_eccentric_footprints(func):
         padding = False
         if out is None:
             out = np.empty_like(image)
-        for axis_len in footprint.shape:
+        if _footprint_is_sequence(footprint):
+            # Note: in practice none of our built-in footprint sequences will
+            #       require padding (all are symmetric and have odd sizes)
+            footprint_shape = _shape_from_sequence(footprint)
+        else:
+            footprint_shape = footprint.shape
+        for axis_len in footprint_shape:
             if axis_len % 2 == 0:
                 axis_pad_width = axis_len - 1
                 padding = True
@@ -132,8 +156,6 @@ def pad_for_eccentric_footprints(func):
 
 
 @default_footprint
-@deprecate_kwarg(kwarg_mapping={'selem': 'footprint'}, removed_version="1.0",
-                 deprecated_version="0.19")
 def erosion(image, footprint=None, out=None, shift_x=False, shift_y=False):
     """Return grayscale morphological erosion of an image.
 
@@ -145,9 +167,11 @@ def erosion(image, footprint=None, out=None, shift_x=False, shift_y=False):
     ----------
     image : ndarray
         Image array.
-    footprint : ndarray, optional
-        The neighborhood expressed as an array of 1's and 0's.
-        If None, use cross-shaped footprint (connectivity=1).
+    footprint : ndarray or tuple, optional
+        The neighborhood expressed as a 2-D array of 1's and 0's.
+        If None, use a cross-shaped footprint (connectivity=1). The footprint
+        can also be provided as a sequence of smaller footprints as described
+        in the notes below.
     out : ndarrays, optional
         The array to store the result of the morphology. If None is
         passed, a new array will be allocated.
@@ -167,6 +191,16 @@ def erosion(image, footprint=None, out=None, shift_x=False, shift_y=False):
     lower algorithm complexity makes the `skimage.filters.rank.minimum`
     function more efficient for larger images and footprints.
 
+    The footprint can also be a provided as a sequence of 2-tuples where the
+    first element of each 2-tuple is a footprint ndarray and the second element
+    is an integer describing the number of times it should be iterated. For
+    example ``footprint=[(np.ones((9, 1)), 1), (np.ones((1, 9)), 1)]``
+    would apply a 9x1 footprint followed by a 1x9 footprint resulting in a net
+    effect that is the same as ``footprint=np.ones((9, 9))``, but with lower
+    computational cost. Most of the builtin footprints such as
+    ``skimage.morphology.disk`` provide an option to automatically generate a
+    footprint sequence of this type.
+
     Examples
     --------
     >>> # Erosion shrinks bright regions
@@ -185,17 +219,21 @@ def erosion(image, footprint=None, out=None, shift_x=False, shift_y=False):
            [0, 0, 0, 0, 0]], dtype=uint8)
 
     """
-    footprint = np.array(footprint)
-    footprint = _shift_footprint(footprint, shift_x, shift_y)
     if out is None:
         out = np.empty_like(image)
+
+    if _footprint_is_sequence(footprint):
+        footprints = tuple((_shift_footprint(fp, shift_x, shift_y), n)
+                           for fp, n in footprint)
+        return _iterate_gray_func(ndi.grey_erosion, image, footprints, out)
+
+    footprint = np.array(footprint)
+    footprint = _shift_footprint(footprint, shift_x, shift_y)
     ndi.grey_erosion(image, footprint=footprint, output=out)
     return out
 
 
 @default_footprint
-@deprecate_kwarg(kwarg_mapping={'selem': 'footprint'}, removed_version="1.0",
-                 deprecated_version="0.19")
 def dilation(image, footprint=None, out=None, shift_x=False, shift_y=False):
     """Return grayscale morphological dilation of an image.
 
@@ -208,9 +246,11 @@ def dilation(image, footprint=None, out=None, shift_x=False, shift_y=False):
     ----------
     image : ndarray
         Image array.
-    footprint : ndarray, optional
-        The neighborhood expressed as an array of 1's and 0's.
-        If None, use cross-shaped footprint (connectivity=1).
+    footprint : ndarray or tuple, optional
+        The neighborhood expressed as a 2-D array of 1's and 0's.
+        If None, use a cross-shaped footprint (connectivity=1). The footprint
+        can also be provided as a sequence of smaller footprints as described
+        in the notes below.
     out : ndarray, optional
         The array to store the result of the morphology. If None is
         passed, a new array will be allocated.
@@ -230,6 +270,16 @@ def dilation(image, footprint=None, out=None, shift_x=False, shift_y=False):
     algorithm complexity makes the `skimage.filters.rank.maximum` function more
     efficient for larger images and footprints.
 
+    The footprint can also be a provided as a sequence of 2-tuples where the
+    first element of each 2-tuple is a footprint ndarray and the second element
+    is an integer describing the number of times it should be iterated. For
+    example ``footprint=[(np.ones((9, 1)), 1), (np.ones((1, 9)), 1)]``
+    would apply a 9x1 footprint followed by a 1x9 footprint resulting in a net
+    effect that is the same as ``footprint=np.ones((9, 9))``, but with lower
+    computational cost. Most of the builtin footprints such as
+    ``skimage.morphology.disk`` provide an option to automatically generate a
+    footprint sequence of this type.
+
     Examples
     --------
     >>> # Dilation enlarges bright regions
@@ -248,6 +298,17 @@ def dilation(image, footprint=None, out=None, shift_x=False, shift_y=False):
            [0, 0, 0, 0, 0]], dtype=uint8)
 
     """
+    if out is None:
+        out = np.empty_like(image)
+
+    if _footprint_is_sequence(footprint):
+        # shift and invert (see comment below) each footprint
+        footprints = tuple(
+            (_invert_footprint(_shift_footprint(fp, shift_x, shift_y)), n)
+            for fp, n in footprint
+        )
+        return _iterate_gray_func(ndi.grey_dilation, image, footprints, out)
+
     footprint = np.array(footprint)
     footprint = _shift_footprint(footprint, shift_x, shift_y)
     # Inside ndi.grey_dilation, the footprint is inverted,
@@ -256,14 +317,11 @@ def dilation(image, footprint=None, out=None, shift_x=False, shift_y=False):
     # footprint before passing it to `ndi.grey_dilation`.
     # [1] https://github.com/scipy/scipy/blob/ec20ababa400e39ac3ffc9148c01ef86d5349332/scipy/ndimage/morphology.py#L1285  # noqa
     footprint = _invert_footprint(footprint)
-    if out is None:
-        out = np.empty_like(image)
+
     ndi.grey_dilation(image, footprint=footprint, output=out)
     return out
 
 
-@deprecate_kwarg(kwarg_mapping={'selem': 'footprint'}, removed_version="1.0",
-                 deprecated_version="0.19")
 @default_footprint
 @pad_for_eccentric_footprints
 def opening(image, footprint=None, out=None):
@@ -278,9 +336,11 @@ def opening(image, footprint=None, out=None):
     ----------
     image : ndarray
         Image array.
-    footprint : ndarray, optional
-        The neighborhood expressed as an array of 1's and 0's.
-        If None, use cross-shaped footprint (connectivity=1).
+    footprint : ndarray or tuple, optional
+        The neighborhood expressed as a 2-D array of 1's and 0's.
+        If None, use a cross-shaped footprint (connectivity=1). The footprint
+        can also be provided as a sequence of smaller footprints as described
+        in the notes below.
     out : ndarray, optional
         The array to store the result of the morphology. If None
         is passed, a new array will be allocated.
@@ -290,6 +350,18 @@ def opening(image, footprint=None, out=None):
     opening : array, same shape and type as `image`
         The result of the morphological opening.
 
+    Notes
+    -----
+    The footprint can also be a provided as a sequence of 2-tuples where the
+    first element of each 2-tuple is a footprint ndarray and the second element
+    is an integer describing the number of times it should be iterated. For
+    example ``footprint=[(np.ones((9, 1)), 1), (np.ones((1, 9)), 1)]``
+    would apply a 9x1 footprint followed by a 1x9 footprint resulting in a net
+    effect that is the same as ``footprint=np.ones((9, 9))``, but with lower
+    computational cost. Most of the builtin footprints such as
+    ``skimage.morphology.disk`` provide an option to automatically generate a
+    footprint sequence of this type.
+
     Examples
     --------
     >>> # Open up gap between two bright regions (but also shrink regions)
@@ -314,8 +386,6 @@ def opening(image, footprint=None, out=None):
     return out
 
 
-@deprecate_kwarg(kwarg_mapping={'selem': 'footprint'}, removed_version="1.0",
-                 deprecated_version="0.19")
 @default_footprint
 @pad_for_eccentric_footprints
 def closing(image, footprint=None, out=None):
@@ -330,9 +400,11 @@ def closing(image, footprint=None, out=None):
     ----------
     image : ndarray
         Image array.
-    footprint : ndarray, optional
-        The neighborhood expressed as an array of 1's and 0's.
-        If None, use cross-shaped footprint (connectivity=1).
+    footprint : ndarray or tuple, optional
+        The neighborhood expressed as a 2-D array of 1's and 0's.
+        If None, use a cross-shaped footprint (connectivity=1). The footprint
+        can also be provided as a sequence of smaller footprints as described
+        in the notes below.
     out : ndarray, optional
         The array to store the result of the morphology. If None,
         a new array will be allocated.
@@ -342,6 +414,18 @@ def closing(image, footprint=None, out=None):
     closing : array, same shape and type as `image`
         The result of the morphological closing.
 
+    Notes
+    -----
+    The footprint can also be a provided as a sequence of 2-tuples where the
+    first element of each 2-tuple is a footprint ndarray and the second element
+    is an integer describing the number of times it should be iterated. For
+    example ``footprint=[(np.ones((9, 1)), 1), (np.ones((1, 9)), 1)]``
+    would apply a 9x1 footprint followed by a 1x9 footprint resulting in a net
+    effect that is the same as ``footprint=np.ones((9, 9))``, but with lower
+    computational cost. Most of the builtin footprints such as
+    ``skimage.morphology.disk`` provide an option to automatically generate a
+    footprint sequence of this type.
+
     Examples
     --------
     >>> # Close a gap between two bright lines
@@ -366,9 +450,24 @@ def closing(image, footprint=None, out=None):
     return out
 
 
+def _white_tophat_seqence(image, footprints, out):
+    """Return white top hat for a sequence of footprints.
+
+    Like SciPy's implementation, but with ``ndi.grey_erosion`` and
+    ``ndi.grey_dilation`` wrapped with ``_iterate_gray_func``.
+    """
+    tmp = _iterate_gray_func(ndi.grey_erosion, image, footprints, out)
+    tmp = _iterate_gray_func(ndi.grey_dilation, tmp.copy(), footprints, out)
+    if tmp is None:
+        tmp = out
+    if image.dtype == np.bool_ and tmp.dtype == np.bool_:
+        np.bitwise_xor(image, tmp, out=tmp)
+    else:
+        np.subtract(image, tmp, out=tmp)
+    return tmp
+
+
 @default_footprint
-@deprecate_kwarg(kwarg_mapping={'selem': 'footprint'}, removed_version="1.0",
-                 deprecated_version="0.19")
 def white_tophat(image, footprint=None, out=None):
     """Return white top hat of an image.
 
@@ -380,9 +479,11 @@ def white_tophat(image, footprint=None, out=None):
     ----------
     image : ndarray
         Image array.
-    footprint : ndarray, optional
-        The neighborhood expressed as an array of 1's and 0's.
-        If None, use cross-shaped footprint (connectivity=1).
+    footprint : ndarray or tuple, optional
+        The neighborhood expressed as a 2-D array of 1's and 0's.
+        If None, use a cross-shaped footprint (connectivity=1). The footprint
+        can also be provided as a sequence of smaller footprints as described
+        in the notes below.
     out : ndarray, optional
         The array to store the result of the morphology. If None
         is passed, a new array will be allocated.
@@ -392,6 +493,18 @@ def white_tophat(image, footprint=None, out=None):
     out : array, same shape and type as `image`
         The result of the morphological white top hat.
 
+    Notes
+    -----
+    The footprint can also be a provided as a sequence of 2-tuples where the
+    first element of each 2-tuple is a footprint ndarray and the second element
+    is an integer describing the number of times it should be iterated. For
+    example ``footprint=[(np.ones((9, 1)), 1), (np.ones((1, 9)), 1)]``
+    would apply a 9x1 footprint followed by a 1x9 footprint resulting in a net
+    effect that is the same as ``footprint=np.ones((9, 9))``, but with lower
+    computational cost. Most of the builtin footprints such as
+    ``skimage.morphology.disk`` provide an option to automatically generate a
+    footprint sequence of this type.
+
     See Also
     --------
     black_tophat
@@ -418,7 +531,6 @@ def white_tophat(image, footprint=None, out=None):
            [0, 0, 0, 0, 0]], dtype=uint8)
 
     """
-    footprint = np.array(footprint)
     if out is image:
         opened = opening(image, footprint)
         if np.issubdtype(opened.dtype, bool):
@@ -437,13 +549,14 @@ def white_tophat(image, footprint=None, out=None):
         out_ = out.view(dtype=np.uint8)
     else:
         out_ = out
+    if _footprint_is_sequence(footprint):
+        return _white_tophat_seqence(image_, footprint, out_)
+    footprint = np.array(footprint)
     out_ = ndi.white_tophat(image_, footprint=footprint, output=out_)
     return out
 
 
 @default_footprint
-@deprecate_kwarg(kwarg_mapping={'selem': 'footprint'}, removed_version="1.0",
-                 deprecated_version="0.19")
 def black_tophat(image, footprint=None, out=None):
     """Return black top hat of an image.
 
@@ -456,9 +569,11 @@ def black_tophat(image, footprint=None, out=None):
     ----------
     image : ndarray
         Image array.
-    footprint : ndarray, optional
+    footprint : ndarray or tuple, optional
         The neighborhood expressed as a 2-D array of 1's and 0's.
-        If None, use cross-shaped footprint (connectivity=1).
+        If None, use a cross-shaped footprint (connectivity=1). The footprint
+        can also be provided as a sequence of smaller footprints as described
+        in the notes below.
     out : ndarray, optional
         The array to store the result of the morphology. If None
         is passed, a new array will be allocated.
@@ -468,6 +583,18 @@ def black_tophat(image, footprint=None, out=None):
     out : array, same shape and type as `image`
         The result of the morphological black top hat.
 
+    Notes
+    -----
+    The footprint can also be a provided as a sequence of 2-tuples where the
+    first element of each 2-tuple is a footprint ndarray and the second element
+    is an integer describing the number of times it should be iterated. For
+    example ``footprint=[(np.ones((9, 1)), 1), (np.ones((1, 9)), 1)]``
+    would apply a 9x1 footprint followed by a 1x9 footprint resulting in a net
+    effect that is the same as ``footprint=np.ones((9, 9))``, but with lower
+    computational cost. Most of the builtin footprints such as
+    ``skimage.morphology.disk`` provide an option to automatically generate a
+    footprint sequence of this type.
+
     See Also
     --------
     white_tophat
