@@ -8,8 +8,8 @@ different levels are represented by parent-child relationships.
 
 These representations allow efficient implementations of many algorithms, such
 as attribute operators. Unlike morphological openings and closings, these
-operators do not require a fixed structuring element, but rather act with a
-flexible structuring element that meets a certain criterion.
+operators do not require a fixed footprint, but rather act with a flexible
+footprint that meets a certain criterion.
 
 This implementation provides functions for:
 1. max-tree generation
@@ -21,20 +21,20 @@ References:
     .. [1] Salembier, P., Oliveras, A., & Garrido, L. (1998). Antiextensive
            Connected Operators for Image and Sequence Processing.
            IEEE Transactions on Image Processing, 7(4), 555-570.
-           :DOI:10.1109/83.663500
+           :DOI:`10.1109/83.663500`
     .. [2] Berger, C., Geraud, T., Levillain, R., Widynski, N., Baillard, A.,
            Bertin, E. (2007). Effective Component Tree Computation with
            Application to Pattern Recognition in Astronomical Imaging.
            In International Conference on Image Processing (ICIP) (pp. 41-44).
-           :DOI:10.1109/ICIP.2007.4379949
+           :DOI:`10.1109/ICIP.2007.4379949`
     .. [3] Najman, L., & Couprie, M. (2006). Building the component tree in
            quasi-linear time. IEEE Transactions on Image Processing, 15(11),
            3531-3539.
-           :DOI:10.1109/TIP.2006.877518
+           :DOI:`10.1109/TIP.2006.877518`
     .. [4] Carlinet, E., & Geraud, T. (2014). A Comparative Review of
            Component Tree Computation Algorithms. IEEE Transactions on Image
            Processing, 23(9), 3885-3895.
-           :DOI:10.1109/TIP.2014.2336551
+           :DOI:`10.1109/TIP.2014.2336551`
 """
 
 import numpy as np
@@ -78,7 +78,6 @@ def max_tree(image, connectivity=1):
     parent : ndarray, int64
         Array of same shape as image. The value of each pixel is the index of
         its parent in the ravelled array.
-
     tree_traverser : 1D array, int64
         The ordered pixel indices (referring to the ravelled array). The pixels
         are ordered such that every pixel is preceded by its parent (except for
@@ -132,7 +131,7 @@ def max_tree(image, connectivity=1):
                                                       offset).astype(np.int32)
 
     # pixels need to be sorted according to their gray level.
-    tree_traverser = np.argsort(image.ravel()).astype(np.int64)
+    tree_traverser = np.argsort(image.ravel(), kind="stable").astype(np.int64)
 
     # call of cython function.
     _max_tree._max_tree(image.ravel(), mask.ravel().astype(np.uint8),
@@ -154,7 +153,7 @@ def area_opening(image, area_threshold=64, connectivity=1,
     area_threshold pixels.
 
     Area openings are similar to morphological openings, but
-    they do not use a fixed structuring element, but rather a deformable
+    they do not use a fixed footprint, but rather a deformable
     one, with surface = area_threshold. Consequently, the area_opening
     with area_threshold=1 is the identity.
 
@@ -189,7 +188,7 @@ def area_opening(image, area_threshold=64, connectivity=1,
     output : ndarray
         Output image of the same shape and type as the input image.
 
-    See also
+    See Also
     --------
     skimage.morphology.area_closing
     skimage.morphology.diameter_opening
@@ -198,7 +197,6 @@ def area_opening(image, area_threshold=64, connectivity=1,
     skimage.morphology.remove_small_objects
     skimage.morphology.remove_small_holes
 
-
     References
     ----------
     .. [1] Vincent L., Proc. "Grayscale area openings and closings,
@@ -208,23 +206,22 @@ def area_opening(image, area_threshold=64, connectivity=1,
            May 1993.
     .. [2] Soille, P., "Morphological Image Analysis: Principles and
            Applications" (Chapter 6), 2nd edition (2003), ISBN 3540429883.
-           :DOI:10.1007/978-3-662-05088-0
+           :DOI:`10.1007/978-3-662-05088-0`
     .. [3] Salembier, P., Oliveras, A., & Garrido, L. (1998). Antiextensive
            Connected Operators for Image and Sequence Processing.
            IEEE Transactions on Image Processing, 7(4), 555-570.
-           :DOI:10.1109/83.663500
+           :DOI:`10.1109/83.663500`
     .. [4] Najman, L., & Couprie, M. (2006). Building the component tree in
            quasi-linear time. IEEE Transactions on Image Processing, 15(11),
            3531-3539.
-           :DOI:10.1109/TIP.2006.877518
+           :DOI:`10.1109/TIP.2006.877518`
     .. [5] Carlinet, E., & Geraud, T. (2014). A Comparative Review of
            Component Tree Computation Algorithms. IEEE Transactions on Image
            Processing, 23(9), 3885-3895.
-           :DOI:10.1109/TIP.2014.2336551
+           :DOI:`10.1109/TIP.2014.2336551`
 
     Examples
     --------
-
     We create an image (quadratic function with a maximum in the center and
     4 additional local maxima.
 
@@ -293,7 +290,7 @@ def diameter_opening(image, diameter_threshold=8, connectivity=1,
     output : ndarray
         Output image of the same shape and type as the input image.
 
-    See also
+    See Also
     --------
     skimage.morphology.area_opening
     skimage.morphology.area_closing
@@ -357,7 +354,7 @@ def area_closing(image, area_threshold=64, connectivity=1,
     area_threshold pixels.
 
     Area closings are similar to morphological closings, but
-    they do not use a fixed structuring element, but rather a deformable
+    they do not use a fixed footprint, but rather a deformable
     one, with surface = area_threshold.
 
     In the binary case, area closings are equivalent to
@@ -392,7 +389,7 @@ def area_closing(image, area_threshold=64, connectivity=1,
     output : ndarray
         Output image of the same shape and type as input image.
 
-    See also
+    See Also
     --------
     skimage.morphology.area_opening
     skimage.morphology.diameter_opening
@@ -424,7 +421,6 @@ def area_closing(image, area_threshold=64, connectivity=1,
            Processing, 23(9), 3885-3895.
            :DOI:`10.1109/TIP.2014.2336551`
 
-
     Examples
     --------
     We create an image (quadratic function with a minimum in the center and
@@ -444,7 +440,6 @@ def area_closing(image, area_threshold=64, connectivity=1,
     All small minima are removed, and the remaining minima have at least
     a size of 8.
 
-
     Notes
     -----
     If a max-tree representation (parent and tree_traverser) are given to the
@@ -513,7 +508,7 @@ def diameter_closing(image, diameter_threshold=8, connectivity=1,
     output : ndarray
         Output image of the same shape and type as input image.
 
-    See also
+    See Also
     --------
     skimage.morphology.area_opening
     skimage.morphology.area_closing
@@ -552,7 +547,6 @@ def diameter_closing(image, diameter_threshold=8, connectivity=1,
     All small minima with a maximal extension of 2 or less are removed.
     The remaining minima have all a maximal extension of at least 3.
 
-
     Notes
     -----
     If a max-tree representation (parent and tree_traverser) are given to the
@@ -596,14 +590,14 @@ def max_tree_local_maxima(image, connectivity=1,
     ----------
     image : ndarray
         The input image for which the maxima are to be calculated.
-    connectivity: unsigned int, optional
+    connectivity : unsigned int, optional
         The neighborhood connectivity. The integer represents the maximum
         number of orthogonal steps to reach a neighbor. In 2D, it is 1 for
         a 4-neighborhood and 2 for a 8-neighborhood. Default value is 1.
-    parent: ndarray, int64, optional
+    parent : ndarray, int64, optional
         The value of each pixel is the index of its parent in the ravelled
         array.
-    tree_traverser: 1D array, int64, optional
+    tree_traverser : 1D array, int64, optional
         The ordered pixel indices (referring to the ravelled array). The pixels
         are ordered such that every pixel is preceded by its parent (except for
         the root which has no parent).
@@ -613,7 +607,7 @@ def max_tree_local_maxima(image, connectivity=1,
     local_max : ndarray, uint64
         Labeled local maxima of the image.
 
-    See also
+    See Also
     --------
     skimage.morphology.local_maxima
     skimage.morphology.max_tree
