@@ -1,7 +1,6 @@
 import numpy as np
 import pytest
 
-from skimage._shared.testing import expected_warnings
 from skimage.morphology import flood, flood_fill
 
 eps = 1e-12
@@ -19,12 +18,6 @@ def test_empty_input():
     assert flood(np.empty((20, 0, 4)), ()).shape == (20, 0, 4)
 
 
-def test_selem_kwarg_deprecation():
-    with expected_warnings(["`selem` is a deprecated argument name"]):
-        output = flood_fill(np.empty(0), (), 2, selem=None)
-    assert output.size == 0
-
-
 def test_float16():
     image = np.array([9., 0.1, 42], dtype=np.float16)
     with pytest.raises(TypeError, match="dtype of `image` is float16"):
@@ -251,3 +244,43 @@ def test_negative_indexing_seed_point():
     image = flood_fill(image, (0, -1), 5)
 
     np.testing.assert_allclose(image, expected)
+
+
+def test_non_adjacent_footprint():
+    # Basic tests for non-adjacent footprints
+    footprint = np.array([[1, 0, 0, 0, 1],
+                          [0, 0, 0, 0, 0],
+                          [0, 0, 1, 0, 0],
+                          [0, 0, 0, 0, 0],
+                          [1, 0, 0, 0, 1]])
+
+    output = flood_fill(np.zeros((5, 6), dtype=np.uint8), (2, 3), 255,
+                        footprint=footprint)
+
+    expected = np.array([[0, 255,   0,   0,   0, 255],
+                         [0,   0,   0,   0,   0,   0],
+                         [0,   0,   0, 255,   0,   0],
+                         [0,   0,   0,   0,   0,   0],
+                         [0, 255,   0,   0,   0, 255]], dtype=np.uint8)
+
+    np.testing.assert_equal(output, expected)
+
+    footprint = np.array([[1, 1, 1, 1, 1],
+                          [1, 1, 1, 1, 1],
+                          [1, 1, 1, 1, 1],
+                          [1, 1, 1, 1, 1],
+                          [1, 1, 1, 1, 1]])
+
+    image = np.zeros((5, 10), dtype=np.uint8)
+    image[:, (3, 7, 8)] = 100
+
+    output = flood_fill(image, (0, 0), 255, footprint=footprint)
+
+    expected = np.array([[255, 255, 255, 100, 255, 255, 255, 100, 100, 0],
+                         [255, 255, 255, 100, 255, 255, 255, 100, 100, 0],
+                         [255, 255, 255, 100, 255, 255, 255, 100, 100, 0],
+                         [255, 255, 255, 100, 255, 255, 255, 100, 100, 0],
+                         [255, 255, 255, 100, 255, 255, 255, 100, 100, 0]],
+                        dtype=np.uint8)
+
+    np.testing.assert_equal(output, expected)
