@@ -1,16 +1,13 @@
-
-import os
-
 import numpy as np
 import scipy.ndimage as ndi
 
-from skimage import io, draw, data_dir
+from skimage import io, draw
 from skimage.data import binary_blobs
 from skimage.util import img_as_ubyte
 from skimage.morphology import skeletonize, skeletonize_3d
 
 from skimage._shared import testing
-from skimage._shared.testing import assert_equal, assert_, parametrize
+from skimage._shared.testing import assert_equal, assert_, parametrize, fetch
 
 # basic behavior tests (mostly copied over from 2D skeletonize)
 
@@ -108,7 +105,7 @@ def check_input(img):
     assert_equal(img, orig)
 
 
-def test_skeletonize_num_neighbours():
+def test_skeletonize_num_neighbors():
     # an empty image
     image = np.zeros((300, 300))
 
@@ -178,11 +175,11 @@ def test_two_hole_image():
 
 def test_3d_vs_fiji():
     # generate an image with blobs and compate its skeleton to
-    # the skeleton generated by FIJI
-    img = binary_blobs(32, 0.05, n_dim=3, seed=1234)
+    # the skeleton generated by FIJI (Plugins>Skeleton->Skeletonize)
+    img = binary_blobs(32, 0.05, n_dim=3, rng=1234)
     img = img[:-2, ...]
     img = img.astype(np.uint8)*255
 
     img_s = skeletonize(img)
-    img_f = io.imread(os.path.join(data_dir, "_blobs_3d_fiji_skeleton.tif"))
+    img_f = io.imread(fetch("data/_blobs_3d_fiji_skeleton.tif"))
     assert_equal(img_s, img_f)
