@@ -67,7 +67,7 @@ def _masked_phase_cross_correlation(reference_image, moving_image,
         if reference_image.shape != moving_image.shape:
             raise ValueError(
                 "Input images have different shapes, moving_mask must "
-                "be explicitely set.")
+                "be explicitly set.")
         moving_mask = reference_mask.astype(bool)
 
     # We need masks to be of the same size as their respective images
@@ -157,7 +157,7 @@ def cross_correlate_masked(arr1, arr2, m1, m2, mode='full', axes=(-2, -1),
     fixed_image = np.asarray(arr1)
     moving_image = np.asarray(arr2)
     float_dtype = _supported_float_type(
-        [fixed_image.dtype, moving_image.dtype]
+        (fixed_image.dtype, moving_image.dtype)
     )
     if float_dtype.kind == 'c':
         raise ValueError("complex-valued arr1, arr2 are not supported")
