@@ -1,8 +1,13 @@
-from __future__ import division
-
 from itertools import product
-
 import numpy as np
+from .._shared import utils
+from .._shared.utils import warn
+
+try:
+    import dask
+    dask_available = True
+except ImportError:
+    dask_available = False
 
 
 def _generate_shifts(ndim, multichannel, max_shifts, shift_steps=1):
@@ -30,7 +35,7 @@ def _generate_shifts(ndim, multichannel, max_shifts, shift_steps=1):
     elif len(shift_steps) != ndim:
         raise ValueError("max_shifts should have length ndim")
 
-    if np.any(np.asarray(shift_steps) < 1):
+    if any(s < 1 for s in shift_steps):
         raise ValueError("shift_steps must all be >= 1")
 
     if multichannel and max_shifts[-1] != 0:
@@ -38,38 +43,13 @@ def _generate_shifts(ndim, multichannel, max_shifts, shift_steps=1):
             "Multichannel cycle spinning should not have shifts along the "
             "last axis.")
 
-    return product(*[range(0, s+1, t) for
+    return product(*[range(0, s + 1, t) for
                      s, t in zip(max_shifts, shift_steps)])
 
 
-def _roll_axes(x, rolls, axes=None):
-    """Apply np.roll along a set of axes.
-
-    Parameters
-    ----------
-    x : array-like
-        Array to roll.
-    rolls : int or sequence
-        The amount to roll along each axis in ``axes``.
-    axes : int or sequence, optional
-        The axes to roll. Default is the first ``len(rolls)`` axes of ``x``.
-
-    Returns
-    -------
-    x : array
-        Data with axes rolled.
-    """
-    if axes is None:
-        axes = np.arange(len(rolls))
-    # Replace this loop with x = np.roll(x, rolls, axes) when NumPy>=1.12
-    # becomes a requirement.
-    for r, a in zip(rolls, axes):
-        x = np.roll(x, r, a)
-    return x
-
-
+@utils.channel_as_last_axis()
 def cycle_spin(x, func, max_shifts, shift_steps=1, num_workers=None,
-               multichannel=False, func_kw={}):
+               func_kw=None, *, channel_axis=None):
     """Cycle spinning (repeatedly apply func to shifted versions of x).
 
     Parameters
@@ -91,11 +71,15 @@ def cycle_spin(x, func, max_shifts, shift_steps=1, num_workers=None,
     num_workers : int or None, optional
         The number of parallel threads to use during cycle spinning. If set to
         ``None``, the full set of available cores are used.
-    multichannel : bool, optional
-        Whether to treat the final axis as channels (no cycle shifts are
-        performed over the channels axis).
     func_kw : dict, optional
         Additional keyword arguments to supply to ``func``.
+    channel_axis : int or None, optional
+        If None, the image is assumed to be a grayscale (single channel) image.
+        Otherwise, this parameter indicates which axis of the array corresponds
+        to channels.
+
+        .. versionadded:: 0.19
+           ``channel_axis`` was added in 0.19.
 
     Returns
     -------
@@ -120,40 +104,42 @@ def cycle_spin(x, func, max_shifts, shift_steps=1, num_workers=None,
     .. [1] R.R. Coifman and D.L. Donoho.  "Translation-Invariant De-Noising".
            Wavelets and Statistics, Lecture Notes in Statistics, vol.103.
            Springer, New York, 1995, pp.125-150.
-           DOI:10.1007/978-1-4612-2544-7_9
+           :DOI:`10.1007/978-1-4612-2544-7_9`
 
     Examples
     --------
     >>> import skimage.data
     >>> from skimage import img_as_float
-    >>> from skimage.restoration import denoise_wavelet, cycle_spin
+    >>> from skimage.restoration import denoise_tv_chambolle, cycle_spin
     >>> img = img_as_float(skimage.data.camera())
     >>> sigma = 0.1
     >>> img = img + sigma * np.random.standard_normal(img.shape)
-    >>> denoised = cycle_spin(img, func=denoise_wavelet, max_shifts=3)
+    >>> denoised = cycle_spin(img, func=denoise_tv_chambolle,
+    ...                       max_shifts=3)
 
     """
+    if func_kw is None:
+        func_kw = {}
+
     x = np.asanyarray(x)
+    multichannel = channel_axis is not None
     all_shifts = _generate_shifts(x.ndim, multichannel, max_shifts,
                                   shift_steps)
     all_shifts = list(all_shifts)
+    roll_axes = tuple(range(x.ndim))
 
     def _run_one_shift(shift):
         # shift, apply function, inverse shift
-        xs = _roll_axes(x, shift)
+        xs = np.roll(x, shift, axis=roll_axes)
         tmp = func(xs, **func_kw)
-        return _roll_axes(tmp, -np.asarray(shift))
+        return np.roll(tmp, tuple(-s for s in shift), axis=roll_axes)
 
-    if num_workers != 1:
-        try:
-            import dask
-        except ImportError:
-            import warnings
-            warnings.warn(
-                "dask is required for parallel computation, but it is "
-                "not available.  Computation will be performed serially."
-            )
-            num_workers = 1
+    if not dask_available and (num_workers is None or num_workers > 1):
+        num_workers = 1
+        warn('The optional dask dependency is not installed. '
+             'The number of workers is set to 1. To silence '
+             'this warning, install dask or explicitly set `num_workers=1` '
+             'when calling the `cycle_spin` function')
     # compute a running average across the cycle shifts
     if num_workers == 1:
         # serial processing
