@@ -2,7 +2,6 @@ import numpy as np
 import pytest
 from numpy.testing import assert_array_equal
 
-from skimage._shared._warnings import expected_warnings
 from skimage._shared.utils import _supported_float_type
 from skimage.segmentation import chan_vese
 
@@ -76,18 +75,12 @@ def test_chan_vese_gap_closing():
     ref = np.zeros((20, 20))
     ref[8:15, :] = np.ones((7, 20))
     img = ref.copy()
-    img[:, 6] = np.zeros((20))
+    img[:, 6] = np.zeros(20)
     result = chan_vese(img, mu=0.7, tol=1e-3, max_num_iter=1000, dt=1000,
                        init_level_set="disk").astype(float)
     assert_array_equal(result, ref)
 
 
-def test_chan_vese_max_iter_deprecation():
-    img = np.zeros((20, 20))
-    with expected_warnings(["`max_iter` is a deprecated argument"]):
-        chan_vese(img, max_iter=10)
-
-
 def test_chan_vese_incorrect_level_set():
     img = np.zeros((10, 10))
     ls = np.zeros((10, 9))
