@@ -2,21 +2,13 @@ import numpy as np
 
 from scipy.interpolate import interp1d
 from scipy.constants import golden_ratio
+from scipy.fft import fft, ifft, fftfreq, fftshift
 from ._warps import warp
 from ._radon_transform import sart_projection_update
-from .._shared.fft import fftmodule
-from .._shared.utils import deprecate_kwarg, convert_to_float
+from .._shared.utils import convert_to_float
 from warnings import warn
 from functools import partial
 
-if fftmodule is np.fft:
-    # fallback from scipy.fft to scipy.fftpack instead of numpy.fft
-    # (fftpack preserves single precision while numpy.fft does not)
-    from scipy.fftpack import fft, ifft
-else:
-    fft = fftmodule.fft
-    ifft = fftmodule.ifft
-
 
 __all__ = ['radon', 'order_angles_golden_ratio', 'iradon', 'iradon_sart']
 
@@ -133,9 +125,9 @@ def _get_fourier_filter(size, filter_name):
 
     Parameters
     ----------
-    size: int
+    size : int
         filter size. Must be even.
-    filter_name: str
+    filter_name : str
         Filter used in frequency domain filtering. Filters available:
         ramp, shepp-logan, cosine, hamming, hann. Assign None to use
         no filter.
@@ -165,24 +157,22 @@ def _get_fourier_filter(size, filter_name):
         pass
     elif filter_name == "shepp-logan":
         # Start from first element to avoid divide by zero
-        omega = np.pi * fftmodule.fftfreq(size)[1:]
+        omega = np.pi * fftfreq(size)[1:]
         fourier_filter[1:] *= np.sin(omega) / omega
     elif filter_name == "cosine":
         freq = np.linspace(0, np.pi, size, endpoint=False)
-        cosine_filter = fftmodule.fftshift(np.sin(freq))
+        cosine_filter = fftshift(np.sin(freq))
         fourier_filter *= cosine_filter
     elif filter_name == "hamming":
-        fourier_filter *= fftmodule.fftshift(np.hamming(size))
+        fourier_filter *= fftshift(np.hamming(size))
     elif filter_name == "hann":
-        fourier_filter *= fftmodule.fftshift(np.hanning(size))
+        fourier_filter *= fftshift(np.hanning(size))
     elif filter_name is None:
         fourier_filter[:] = 1
 
     return fourier_filter[:, np.newaxis]
 
 
-@deprecate_kwarg(kwarg_mapping={'filter': 'filter_name'},
-                 removed_version="0.19")
 def iradon(radon_image, theta=None, output_size=None,
            filter_name="ramp", interpolation="linear", circle=True,
            preserve_range=True):
@@ -227,7 +217,7 @@ def iradon(radon_image, theta=None, output_size=None,
         with indices
         ``(reconstructed.shape[0] // 2, reconstructed.shape[1] // 2)``.
 
-    .. versionchanged :: 0.19
+    .. versionchanged:: 0.19
         In ``iradon``, ``filter`` argument is deprecated in favor of
         ``filter_name``.
 
@@ -259,11 +249,11 @@ def iradon(radon_image, theta=None, output_size=None,
 
     interpolation_types = ('linear', 'nearest', 'cubic')
     if interpolation not in interpolation_types:
-        raise ValueError("Unknown interpolation: %s" % interpolation)
+        raise ValueError(f"Unknown interpolation: {interpolation}")
 
     filter_types = ('ramp', 'shepp-logan', 'cosine', 'hamming', 'hann', None)
     if filter_name not in filter_types:
-        raise ValueError("Unknown filter: %s" % filter_name)
+        raise ValueError(f"Unknown filter: {filter_name}")
 
     radon_image = convert_to_float(radon_image, preserve_range)
     dtype = radon_image.dtype
@@ -474,30 +464,27 @@ def iradon_sart(radon_image, theta=None, image=None, projection_shifts=None,
         theta = np.linspace(0, 180, radon_image.shape[1],
                             endpoint=False, dtype=dtype)
     elif len(theta) != radon_image.shape[1]:
-        raise ValueError('Shape of theta (%s) does not match the '
-                         'number of projections (%d)'
-                         % (len(theta), radon_image.shape[1]))
+        raise ValueError(f'Shape of theta ({len(theta)}) does not match the '
+                         f'number of projections ({radon_image.shape[1]})')
     else:
         theta = np.asarray(theta, dtype=dtype)
 
     if image is None:
         image = np.zeros(reconstructed_shape, dtype=dtype)
     elif image.shape != reconstructed_shape:
-        raise ValueError('Shape of image (%s) does not match first dimension '
-                         'of radon_image (%s)'
-                         % (image.shape, reconstructed_shape))
+        raise ValueError(f'Shape of image ({image.shape}) does not match first dimension '
+                         f'of radon_image ({reconstructed_shape})')
     elif image.dtype != dtype:
-        warn("image dtype does not match output dtype: "
-             "image is cast to {}".format(dtype))
+        warn(f'image dtype does not match output dtype: '
+             f'image is cast to {dtype}')
 
     image = np.asarray(image, dtype=dtype)
 
     if projection_shifts is None:
         projection_shifts = np.zeros((radon_image.shape[1],), dtype=dtype)
     elif len(projection_shifts) != radon_image.shape[1]:
-        raise ValueError('Shape of projection_shifts (%s) does not match the '
-                         'number of projections (%d)'
-                         % (len(projection_shifts), radon_image.shape[1]))
+        raise ValueError(f'Shape of projection_shifts ({len(projection_shifts)}) does not match the '
+                         f'number of projections ({radon_image.shape[1]})')
     else:
         projection_shifts = np.asarray(projection_shifts, dtype=dtype)
     if clip is not None:
