@@ -1,10 +1,17 @@
 from skimage._shared import testing
 from skimage._shared.testing import assert_equal, assert_array_equal
-from skimage._shared._warnings import expected_warnings
 
 import numpy as np
 from skimage.util import montage
 
+# TODO: when minimum numpy dependency is 1.25 use:
+# np..exceptions.AxisError instead of AxisError
+# and remove this try-except
+try:
+    from numpy import AxisError
+except ImportError:
+    from numpy.exceptions import AxisError
+
 
 def test_montage_simple_gray():
     n_images, n_rows, n_cols = 3, 2, 3
@@ -29,8 +36,7 @@ def test_montage_simple_rgb():
             )
     arr_in = arr_in.reshape(n_images, n_rows, n_cols, n_channels)
 
-    with expected_warnings(["`multichannel` is a deprecated argument"]):
-        arr_out = montage(arr_in, multichannel=True)
+    arr_out = montage(arr_in, channel_axis=-1)
     arr_ref = np.array(
         [[[ 0,  1],
           [ 2,  3],
@@ -86,7 +92,7 @@ def test_montage_simple_rgb_channel_axes(channel_axis):
 @testing.parametrize('channel_axis', (4, -5))
 def test_montage_invalid_channel_axes(channel_axis):
     arr_in = np.arange(16, dtype=float).reshape(2, 2, 2, 2)
-    with testing.raises(np.AxisError):
+    with testing.raises(AxisError):
         montage(arr_in, channel_axis=channel_axis)
 
 
@@ -180,10 +186,8 @@ def test_error_ndim():
 
     arr_error = np.random.randn(1, 2, 3)
     with testing.raises(ValueError):
-        with expected_warnings(["'multichannel is a deprecated argument"]):
-            montage(arr_error, multichannel=True)
+        montage(arr_error, channel_axis=-1)
 
     arr_error = np.random.randn(1, 2, 3, 4, 5)
     with testing.raises(ValueError):
-        with expected_warnings(["'multichannel is a deprecated argument"]):
-            montage(arr_error, multichannel=True)
+        montage(arr_error, channel_axis=-1)
